

**** This do file creates data sets for paper "Setting a Good Example? Examining Sibling Spillovers in Educational Achievement Using a Regression Discontinuity Design" by Krzysztof Karbownik and Umut Ozek published in the Journal of Human Resources ****

**** Code created on 07/27/2021 ****

cd "H:\FKOR\Spillovers"

capture log close
log using "Log\data-creation-final.log", replace text

*** Individual DOBs and family IDs ***

use "Data\Raw\scrambled_families_dob_for_kk.dta", clear 
egen temp1 = rownonmiss(birthyear birthmonth birthday)
keep if temp1 == 3
drop temp*

gen dob = mdy(birthmonth, birthday, birthyear)
format dob %td

rename scrambled id
rename scrambled_family famid

save "Data\Temp\Jul21\identifiers.dta", replace

*** Demographics family ***

use "Data\Raw\kk90.dta", clear
gen testyear = "1990"
forvalues i = 91(1)99 {
append using "Data\Raw\kk`i'.dta"
replace testyear = "19`i'" if testyear == ""
}
foreach i in 00 01 02 03 04 05 {
append using "Data\Raw\kk`i'.dta"
replace testyear = "20`i'" if testyear == ""
}

foreach i in 95 99 {
replace grade = grade`i' if testyear == "19`i'"
replace lunch = lunch`i' if testyear == "19`i'"
}

foreach i in 00 02 {
replace grade = grade`i' if testyear == "20`i'"
replace lunch = lunch`i' if testyear == "20`i'"
}

replace lunch = lunch03 if testyear == "2003"

drop grade9* lunch9* grade0* lunch0*

rename scrambled id

drop if race == ""
 
gen female = (sex == "F")
gen white = (race == "W")
gen black = (race == "B")
gen hispanic = (race == "H")
gen other = (race == "A" | race == "D" | race == "I" | race == "M")

destring testyear, replace
sort id testyear
egen mtestyear = min(testyear), by(id)

foreach i in female white black hispanic other {
gen n`i' = `i' if testyear == mtestyear
egen m_n`i' = max(n`i'), by(id)
drop `i' n`i'
rename m_n`i' `i' 
 }
 
 drop sex race mtestyear
 
 egen temp1 = rowtotal(white black hispanic other)
 keep if temp1 == 1
 drop temp1
 
 sort id testyear
 
 gen temp1 = (grade == "")
 egen temp2 = max(temp1), by(id)
 drop if temp2 == 1
 drop temp*
 
 forvalues i = 1990(1)2004 {
 replace primex = "Z" if primex == "" & testyear == `i'
 }
 
 replace lep = "ZZ" if lep == "TZ" & testyear == 2005
 replace lep = "ZZ" if lep == "" & testyear == 2005
 
 replace grid = . if grid == 0
 replace grid = . if grid == 9999
 
 replace schlnum = "99999" if schlnum == "PRE"
 
 destring lunch, replace
 gen FRL = (lunch > 1)
 
 merge m:1 id using "Data\Temp\Jul21\identifiers.dta"
 keep if _merge == 3
 drop _merge
 
 egen eFRL = max(FRL), by(famid)
 egen fFRL = mean(FRL), by(famid)
 replace fFRL = fFRL*100
 
foreach i in white black hispanic other {
egen e_`i' = max(`i'), by(famid)
}

egen temp1 = rowtotal(e_white e_black e_hispanic e_other)
sort famid birthyear birthmonth
egen temp2 = seq(), by(famid)
egen temp3 = min(temp2), by(famid)

foreach i in white black hispanic other {
gen m_`i' = `i' if temp2 == temp3
egen em_`i' = max(m_`i'), by(famid)
replace e_`i' = em_`i' if temp1 > 1
drop `i' m_`i' em_`i'
rename e_`i' `i'
}

egen temp4 = rowtotal(white black hispanic other)

drop temp*
 
keep famid eFRL fFRL white black hispanic other
duplicates drop
  
save "Data\Temp\Jul21\family-demographics.dta", replace


*** demographic - grades/individual ***

use "Data\Raw\kk90.dta", clear
gen testyear = "1990"
forvalues i = 91(1)99 {
append using "Data\Raw\kk`i'.dta"
replace testyear = "19`i'" if testyear == ""
}
foreach i in 00 01 02 03 04 05 {
append using "Data\Raw\kk`i'.dta"
replace testyear = "20`i'" if testyear == ""
}

foreach i in 95 99 {
replace grade = grade`i' if testyear == "19`i'"
replace lunch = lunch`i' if testyear == "19`i'"
}

foreach i in 00 02 {
replace grade = grade`i' if testyear == "20`i'"
replace lunch = lunch`i' if testyear == "20`i'"
}

replace lunch = lunch03 if testyear == "2003"

drop grade9* lunch9* grade0* lunch0*

rename scrambled id

drop if race == ""
 
gen female = (sex == "F")
gen white = (race == "W")
gen black = (race == "B")
gen hispanic = (race == "H")
gen other = (race == "A" | race == "D" | race == "I" | race == "M")

destring testyear, replace
sort id testyear
egen mtestyear = min(testyear), by(id)

foreach i in female white black hispanic other {
gen n`i' = `i' if testyear == mtestyear
egen m_n`i' = max(n`i'), by(id)
drop `i' n`i'
rename m_n`i' `i' 
 }
 
 drop sex race mtestyear
 
 egen temp1 = rowtotal(white black hispanic other)
 keep if temp1 == 1
 drop temp1
 
 sort id testyear
 
 gen temp1 = (grade == "")
 egen temp2 = max(temp1), by(id)
 drop if temp2 == 1
 drop temp*
 
 forvalues i = 1990(1)2004 {
 replace primex = "Z" if primex == "" & testyear == `i'
 }
 
 replace lep = "ZZ" if lep == "TZ" & testyear == 2005
 replace lep = "ZZ" if lep == "" & testyear == 2005
 
 replace grid = . if grid == 0
 replace grid = . if grid == 9999
 
 replace schlnum = "99999" if schlnum == "PRE"
 
 destring lunch, replace
 gen FRL = (lunch > 1)
 gen RL = (lunch == 3)
 
 drop lunch white black hispanic other
  
 save "Data\Temp\Jul21\demographics90-05.dta", replace
 
 use "Data\Temp\Jul21\demographics90-05.dta", clear
 merge m:1 id using "Data\Temp\Jul21\identifiers.dta"
 keep if _merge == 3
 drop _merge
 merge m:1 famid using "Data\Temp\Jul21\family-demographics.dta"
 keep if _merge == 3
 drop _merge
 save "Data\Temp\Jul21\demographics-ided-90-05.dta", replace

 *** Disabilities ***
 
use "Data\Temp\Jul21\demographics90-05.dta", clear
drop if grade == "PK"
replace grade = "00" if grade == "KG"
destring grade, replace
drop if grade > 8
keep id testyear primex

gen types_grade = ""
replace types_grade = "1" if primex == "J" | primex == "K" | primex == "Q" | primex == "P"
replace types_grade = "2" if primex == "A" | primex == "B" | primex == "G" | primex == "W" | primex == "N" | primex == "T"
replace types_grade = "3" if primex == "C" | primex == "F" | primex == "H" | primex == "I" | primex == "M" | primex == "O" | primex == "R" | primex == "S"
replace types_grade = "4" if primex == "U" | primex == "V" | primex == "D"
replace types_grade = "5" if primex == "L" | primex == "Z"
destring types_grade, replace
lab define t1 1 "Behavioral" 2 "Cognitive" 3 "Physical" 4 "Other" 5 "No"
lab value types_gr t1	

gen gifted = (primex == "L")
ta types_grade, gen(tg)

egen temp1 = max(tg1), by(id)
egen temp2 = max(tg2), by(id)
egen temp3 = max(tg3), by(id)
egen temp4 = max(tg4), by(id)
egen temp5 = max(gifted), by(id)

keep id temp*
duplicates drop

rename temp1 behav
rename temp2 cognit
rename temp3 physi
rename temp4 otherd
rename temp5 gifted

egen edisab = rowtotal(behav cognit physi otherd)
replace edisab = 1 if edisab >= 1

save "Data\Temp\Jul21\disabilities-all.dta", replace

 *** Test scores: ctbs ***

use "Data\Raw\kkctbs88.dta", clear
drop ctbsbatteryscale ctbsreadingscale ctbsmathscale ctbslangscale ctbslangexpressscale ctbslangmechscale ctbsmathappscale ctbsmathcompscale ctbsreadcompscale ctbsvocabscale ctbssciencescale ctbsspellingscale ctbswordanalscale
forvalues i = 89(1)99 {
append using "Data\Raw\kkctbs`i'.dta"
drop ctbsbatteryscale ctbsreadingscale ctbsmathscale ctbslangscale ctbslangexpressscale ctbslangmechscale ctbsmathappscale ctbsmathcompscale ctbsreadcompscale ctbsvocabscale ctbssciencescale ctbsspellingscale ctbswordanalscale
}
rename scrambled id

duplicates tag id testyear, gen(d)

foreach i in ctbsbatterynp ctbsreadingnp ctbsmathnp ctbslangnp ctbslangexpressnp ctbslangmechnp ctbsmathappnp ctbsmathcompnp ctbsreadcompnp ctbsvocabnp ctbssciencenp ctbsspellingnp ctbswordanalnp {
egen m`i' = max(`i') if d > 0, by(id testyear)
replace `i' = m`i' if d > 0
drop m`i'
}
drop d
duplicates drop

save "Data\Temp\Jul21\ctbs88-99.dta", replace

use "Data\Raw\kkfcat00.dta", clear
drop fcatmathscale fcatreadingscale fcatmathscale_sss fcatreadingscale_sss fcatmathlevel fcatreadinglevel
rename scrambled id
gen testyear = 2000
gen test = "FCAT"
rename fcatreadingnp readp
rename fcatmathnp mathp
save "Data\Temp\Jul21\fcat00.dta", replace

use "Data\Raw\kkfcat01.dta", clear
drop nrtmdate nrtmst9 nrtrst9 nrtrsch nrtmsch nrtrsch nrtmsch nrtrgrd nrtmgrd nrtread nrtrdate nrtmath nrtrss nrtmss
rename scrambled id
gen testyear = 2001
gen test = "FCAT"
rename nrtrnp readp
rename nrtmnp mathp
save "Data\Temp\Jul21\fcat01.dta", replace

use "Data\Raw\kkfcat02.dta", clear
drop nrtmst9 nrtrst9 nrtmss nrtrss nrtmnce nrtrnce
rename scrambled id
gen testyear = 2002
gen test = "FCAT"
rename nrtrnp readp
rename nrtmnp mathp
save "Data\Temp\Jul21\fcat02.dta", replace

use "Data\Raw\kkfcat03.dta", clear
drop nrtmss nrtmst9 nrtmnce nrtrss nrtrst9 nrtrnce
rename scrambled id
gen testyear = 2003
gen test = "FCAT"
rename nrtrnp readp
rename nrtmnp mathp
save "Data\Temp\Jul21\fcat03.dta", replace

use "Data\Raw\kkfcat04.dta", clear
drop nrtmss nrtmst9 nrtmnce nrtrss nrtrst9 nrtrnce
rename scrambled id
gen testyear = 2004
gen test = "FCAT"
rename nrtrnp readp
rename nrtmnp mathp
save "Data\Temp\Jul21\fcat04.dta", replace

use "Data\Raw\kkfcat05.dta", clear
drop nrtreads nrtrea_a nrtreadn nrtrea_b nrtmaths nrtmat_a nrtmathn nrtmat_b
rename scrambled id
gen testyear = 2005
gen test = "FCAT"
rename nrtreadp readp
rename nrtmathp mathp
save "Data\Temp\Jul21\fcat05.dta", replace

use "Data\Temp\Jul21\ctbs88-99.dta", clear
keep id testyear ctbsreadingnp ctbsmathnp
rename ctbsreadingnp readp
rename ctbsmathnp mathp
gen test = "CTB"
save "Data\Temp\Jul21\ctbs88-99-math-read.dta", replace

use "Data\Temp\Jul21\ctbs88-99-math-read.dta", clear
append using "Data\Temp\Jul21\fcat00.dta"
append using "Data\Temp\Jul21\fcat01.dta"
append using "Data\Temp\Jul21\fcat02.dta"
append using "Data\Temp\Jul21\fcat03.dta"
append using "Data\Temp\Jul21\fcat04.dta"
append using "Data\Temp\Jul21\fcat05.dta"
keep if testyear >= 1990
save "Data\Temp\Jul21\scores-math-read-90-05.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id testyear grade
keep if grade == "03"

egen temp1 = min(testyear), by(id)
keep if temp1 == testyear

 merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
 keep if _merge == 3
 drop _merge
 
 egen scorep = rowmean(mathp readp)
 keep if scorep != .
 keep id scorep
 rename id id_sib
 rename scorep scorep_sib
 save "Data\Temp\Jul21\grade3score.dta", replace

*** Timing relative to siblings ***

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id testyear birthyear birthmonth birthday dob

gen Age = .
replace Age = (testyear - birthyear) - 1 if birthmonth<9
replace Age = (testyear - birthyear) - 2 if birthmonth>=9

replace Age = Age+1 if birthmonth == 9 & birthday == 1

keep if Age == 5
gen yeara = testyear - 1
gen yearb = testyear
gen yearc = testyear + 1

keep id year*

reshape long year, i(id) j(trt) string
replace trt = "-1" if trt == "a"
replace trt = "0" if trt == "b"
replace trt = "1" if trt == "c"
destring trt, replace
rename trt timing
sort id year
rename year testyear
rename id id_sib

save "Data\Temp\Jul21\sibling-age5-timing.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id testyear birthyear birthmonth birthday dob

gen Age = .
replace Age = (testyear - birthyear) - 1 if birthmonth<9
replace Age = (testyear - birthyear) - 2 if birthmonth>=9

replace Age = Age+1 if birthmonth == 9 & birthday == 1

keep if Age == 5
gen year1 = testyear - 3
gen year2 = testyear - 2
gen year3 = testyear - 1
gen year4 = testyear
gen year5 = testyear + 1
gen year6 = testyear + 2

keep id year*

reshape long year, i(id) j(trt)
replace trt = trt-4

rename trt timing
sort id year
rename year testyear
rename id id_sib

save "Data\Temp\Jul21\sibling-age5-timing-v2.dta", replace

**** Building final data sets ****

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear

drop if famid == ""

merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
keep if _merge == 3
drop _merge

keep if birthyear>=1973 & birthyear<=2000

replace grade = "00" if grade == "KG"
replace grade = "-01" if grade == "PK"
destring grade, replace

replace mathp = . if grade < 3 | grade > 8
replace readp = . if grade < 3 | grade > 8

gen temp1 = (mathp != . | readp != .)
egen temp2 = max(temp1), by(id)
keep if temp2 == 1
drop temp*

keep id famid birthyear birthmonth birthday dob
duplicates drop

egen temp1 = count(dob), by(famid)
drop if temp1 == 1

egen temp2 = count(dob), by(famid birthyear birthmonth)
egen temp3 = max(temp2), by(famid)
drop if temp3 > 1

sort famid dob
egen BO = seq(), by(famid)

sort famid BO
by famid: gen id_sib=id[_n-1]
by famid: gen birthyear_sib=birthyear[_n-1]
by famid: gen birthmonth_sib=birthmonth[_n-1]
by famid: gen dob_sib=dob[_n-1]

gen age_dif = dob-dob_sib
gen age_dif1 = age_dif/30
keep if age_dif1 >=8 & age_dif1 <=96
keep id id_sib BO age_dif dob dob_sib
drop if id_sib==""
format dob_sib %td

duplicates drop

sort id

save "Data\Temp\Jul21\adj_siblings-expanded.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id famid birthmonth birthyear birthday dob female white black hispanic other
duplicates drop
drop if famid == ""

keep if birthyear>=1973 & birthyear<=2000

egen temp1 = count(dob), by(famid)
drop if temp1 == 1

egen temp2 = count(dob), by(famid birthyear birthmonth)
egen temp3 = max(temp2), by(famid)
drop if temp3 > 1

rename id id_sib

gen cutoff1=""
forvalues i = 1970(1)1974{
replace cutoff1="01-01-`i'" if (birthyear==`i'-1 & birthmonth>6) | (birthyear==`i' & birthmonth<=6)
}
replace cutoff1="01-01-1975" if (birthyear==1974 & birthmonth>6) | (birthyear==1975 & birthmonth<6)

replace cutoff1="12-01-1975" if (birthyear==1975 & birthmonth>5) | (birthyear==1976 & birthmonth<5)
replace cutoff1="11-01-1976" if (birthyear==1976 & birthmonth>4) | (birthyear==1977 & birthmonth<4)
replace cutoff1="10-01-1977" if (birthyear==1977 & birthmonth>3) | (birthyear==1978 & birthmonth<3)
forvalues i = 1978(1)2000 {
replace cutoff1="09-01-`i'" if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

drop if cutoff1==""
gen cutoff=date(cutoff1, "MDY")

gen birth_dif=dob-cutoff

gen coh=.
forvalues i = 1970(1)1974{
replace coh=`i' if (birthyear==`i'-1 & birthmonth>6) | (birthyear==`i' & birthmonth<=6)
}
replace coh=1975 if (birthyear==1974 & birthmonth>6) | (birthyear==1975 & birthmonth<6)
replace coh=1976 if (birthyear==1975 & birthmonth>5) | (birthyear==1976 & birthmonth<5)
replace coh=1977 if (birthyear==1976 & birthmonth>4) | (birthyear==1977 & birthmonth<4)
replace coh=1978 if (birthyear==1977 & birthmonth>3) | (birthyear==1978 & birthmonth<3)
forvalues i = 1978(1)2000 {
replace coh=`i'+1 if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

keep id_sib famid birthmonth birthyear birthday dob female white black hispanic other birth_dif coh

foreach i in birthmonth birthyear birthday female white black hispanic other dob birth_dif coh {
rename `i' `i'_sib
}

save "Data\Temp\Jul21\birth_dates_sib.dta", replace

*** Birth order
 
use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id famid birthyear birthmonth birthday dob
duplicates drop

drop if famid == ""

keep if birthyear>=1979
drop if birthmonth <= 8 & birthyear == 1979

egen temp1 = count(dob), by(famid)
drop if temp1 == 1

egen temp2 = count(dob), by(famid birthyear birthmonth)
egen temp3 = max(temp2), by(famid)
drop if temp3 > 1

sort famid dob
egen BO = seq(), by(famid)

keep id BO

duplicates drop

save "Data\Temp\Jul21\birth-oder-siblings.dta", replace

*** Older on younger outcomes ***

use "Data\Temp\Jul21\adj_siblings-expanded.dta", clear
merge 1:1 id_sib using "Data\Temp\Jul21\birth_dates_sib.dta"
keep if _merge == 3
drop _merge

merge 1:m id using "Data\Temp\Jul21\demographics-ided-90-05.dta"
keep if _merge == 3
drop _merge

merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
keep if _merge == 1 | _merge == 3
drop _merge

rename id idY
rename id_sib idO

save "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", replace

*** Younger on older outcomes ***

use "Data\Temp\Jul21\adj_siblings-expanded.dta", clear
rename id_sib idO
rename id id_sib
merge 1:1 id_sib using "Data\Temp\Jul21\birth_dates_sib.dta"
keep if _merge == 3
drop _merge

rename idO id

merge 1:m id using "Data\Temp\Jul21\demographics-ided-90-05.dta"
keep if _merge == 3
drop _merge

merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
keep if _merge == 1 | _merge == 3
drop _merge

rename id idO
rename id_sib idY

save "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", replace

**** Auxiliary data sets *****

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id testyear grade
rename id idY
rename grade gradeY
save "Data\Temp\Jul21\gradesyounger.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta",  clear
keep if birthyear >= 1976 & birthyear <= 1996
sort id testyear
keep id famid
duplicates drop
egen temp1 = count(id), by(famid)
drop if temp1 == 1
keep id
save "Data\Temp\Jul21\two-plus-families.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id testyear grade birthday birthmonth birthyear
keep if grade == "KG"
egen temp1 = min(testyear), by(id)
keep if temp1 == testyear

gen Age = .
replace Age = (testyear - birthyear) - 1 if birthmonth<9
replace Age = (testyear - birthyear) - 2 if birthmonth>=9 /*generating age at Sep 1st each year; not that we code each school year to spring examination and hence we need to subtract here */

replace Age = Age+1 if birthmonth == 9 & birthday == 1

keep if Age >= 2 & Age <= 10

gen hb = .
gen ontime = .
gen early = .

replace hb = 1 if Age >= 6
replace hb = 0 if hb == .

replace ontime = 1 if Age == 5
replace ontime = 0 if ontime == .

replace early = 1 if Age < 5
replace early = 0 if early == .

rename id id_sib
rename hb hb_sib
rename ontime ontime_sib
rename early early_sib
rename Age Age_sib
keep id_sib hb_sib ontime_sib early_sib Age_sib
duplicates drop
save "Data\Temp\Jul21\KGgradeobs.dta", replace

use "Data\Raw\grid_char.dta", clear

keep grid testyear grid_rmed_inc grid_rlths grid_rcol grid_rsing_moth

save "Data\Temp\Jul21\neigh-characteristics-measures.dta", replace

use "Data\Raw\kk90.dta", clear
gen testyear = "1990"
forvalues i = 91(1)99 {
append using "Data\Raw\kk`i'.dta"
replace testyear = "19`i'" if testyear == ""
}
foreach i in 00 01 02 03 04 05 {
append using "Data\Raw\kk`i'.dta"
replace testyear = "20`i'" if testyear == ""
}

foreach i in 95 99 {
replace grade = grade`i' if testyear == "19`i'"
replace lunch = lunch`i' if testyear == "19`i'"
}

foreach i in 00 02 {
replace grade = grade`i' if testyear == "20`i'"
replace lunch = lunch`i' if testyear == "20`i'"
}

replace lunch = lunch03 if testyear == "2003"

drop grade9* lunch9* grade0* lunch0*

rename scrambled id

drop if race == ""
 
gen female = (sex == "F")
gen white = (race == "W")
gen black = (race == "B")
gen hispanic = (race == "H")
gen other = (race == "A" | race == "D" | race == "I" | race == "M")

destring testyear, replace
sort id testyear
egen mtestyear = min(testyear), by(id)

foreach i in female white black hispanic other {
gen n`i' = `i' if testyear == mtestyear
egen m_n`i' = max(n`i'), by(id)
drop `i' n`i'
rename m_n`i' `i' 
}
 
drop sex race mtestyear
 
egen temp1 = rowtotal(white black hispanic other)
keep if temp1 == 1
drop temp1
 
sort id testyear
 
gen temp1 = (grade == "")
egen temp2 = max(temp1), by(id)
drop if temp2 == 1
drop temp*
 
forvalues i = 1990(1)2004 {
replace primex = "Z" if primex == "" & testyear == `i'
}
 
replace lep = "ZZ" if lep == "TZ" & testyear == 2005
replace lep = "ZZ" if lep == "" & testyear == 2005
 
replace grid = . if grid == 0
replace grid = . if grid == 9999
 
replace schlnum = "99999" if schlnum == "PRE"
 
destring lunch, replace
gen FRL = (lunch > 1)
 
merge m:1 id using "Data\Temp\Jul21\identifiers.dta"
keep if _merge == 3
drop _merge

drop if grid == .
 
merge m:1 grid testyear using "Data\Temp\Jul21\neigh-characteristics-measures.dta"
keep if _merge == 3
drop _merge
 
keep id testyear grid_rmed_inc grid_rlths grid_rcol grid_rsing_moth

rename grid_rmed_inc neigh_inc
rename grid_rlths neigh_hsd
rename grid_rcol neigh_colg
rename grid_rsing_moth neigh_singmom
  
save "Data\Temp\Jul21\idiv-nighb-chars.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id testyear grade birthday birthmonth birthyear
keep if grade == "PK"
egen temp1 = max(testyear), by(id)
keep if temp1 == testyear

keep id 
rename id id_sib
duplicates drop
save "Data\Temp\Jul21\PREKGgradeobs-testyear.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id testyear grade birthday birthmonth birthyear
keep if grade == "KG"
egen temp1 = min(testyear), by(id)
keep if temp1 == testyear

gen Age = .
replace Age = (testyear - birthyear) - 1 if birthmonth<9
replace Age = (testyear - birthyear) - 2 if birthmonth>=9 /*generating age at Sep 1st each year; not that we code each school year to spring examination and hence we need to subtract here */

replace Age = Age+1 if birthmonth == 9 & birthday == 1

keep if Age >= 2 & Age <= 10

gen hb = .
gen ontime = .
gen early = .

replace hb = 1 if Age >= 6
replace hb = 0 if hb == .

replace ontime = 1 if Age == 5
replace ontime = 0 if ontime == .

replace early = 1 if Age < 5
replace early = 0 if early == .

rename id id_sib
rename hb hb_sib
rename ontime ontime_sib
rename early early_sib
rename Age Age_sib
rename testyear testyear_sib
keep id_sib hb_sib ontime_sib early_sib Age_sib testyear_sib
duplicates drop
merge 1:1 id_sib using "Data\Temp\Jul21\PREKGgradeobs-testyear.dta"
keep if _merge == 1 | _merge == 3
gen pk_sib = (_merge == 3)
drop _merge
save "Data\Temp\Jul21\KGgradeobs-testyear.dta", replace

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear

drop if famid == ""

merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
keep if _merge == 3
drop _merge

keep if birthyear>=1973 & birthyear<=2000

replace grade = "00" if grade == "KG"
replace grade = "-01" if grade == "PK"
destring grade, replace

replace mathp = . if grade < 3 | grade > 8
replace readp = . if grade < 3 | grade > 8

gen temp1 = (mathp != . | readp != .)
egen temp2 = max(temp1), by(id)
keep if temp2 == 1
drop temp*

keep id famid birthyear birthmonth birthday dob
duplicates drop

egen temp1 = count(dob), by(famid)
drop if temp1 == 1

egen temp2 = count(dob), by(famid birthyear birthmonth)
egen temp3 = max(temp2), by(famid)
drop if temp3 > 1

sort famid dob
egen BO = seq(), by(famid)

sort famid BO
by famid: gen id_sib=id[_n-1]
by famid: gen birthyear_sib=birthyear[_n-1]
by famid: gen birthmonth_sib=birthmonth[_n-1]
by famid: gen dob_sib=dob[_n-1]

gen age_dif = dob-dob_sib
gen age_dif1 = age_dif/30
egen age_dif2 = max(age_dif1), by(famid)
keep if age_dif2 >=8 & age_dif2 <=96

drop id_sib birthyear_sib birthmonth_sib dob_sib age_dif* temp*

keep if birthyear >= 1976 & birthyear <= 1996

gen cutoff1=""

replace cutoff1="11-01-1976" if (birthyear==1976 & birthmonth>4) | (birthyear==1977 & birthmonth<4)
replace cutoff1="10-01-1977" if (birthyear==1977 & birthmonth>3) | (birthyear==1978 & birthmonth<3)
forvalues i = 1978(1)1995 {
replace cutoff1="09-01-`i'" if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

drop if cutoff1==""
gen cutoff=date(cutoff1, "MDY")

gen birth_dif=dob-cutoff

gen coh=.

replace coh=1977 if (birthyear==1976 & birthmonth>4) | (birthyear==1977 & birthmonth<4)
replace coh=1978 if (birthyear==1977 & birthmonth>3) | (birthyear==1978 & birthmonth<3)
forvalues i = 1978(1)1995 {
replace coh=`i'+1 if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

merge m:1 famid using  "Data\Temp\Jul21\family-demographics.dta"
keep if _merge == 3
drop _merge

merge 1:m id using "Data\Temp\Jul21\demographics90-05.dta"
keep if _merge == 3
drop _merge

merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
keep if _merge == 1 | _merge == 3
drop _merge

merge m:1 id using "Data\Temp\Jul21\disabilities-all.dta"
keep if _merge == 3
drop _merge

drop cutoff*

save "Data\Temp\Jul21\sibling-sample-as-singletons.dta", replace

log close