
**** This do file creates figures and tables for paper "Setting a Good Example? Examining Sibling Spillovers in Educational Achievement Using a Regression Discontinuity Design" by Krzysztof Karbownik and Umut Ozek published in the Journal of Human Resources ****

**** Code created on 08/12/2021 ****

cd "H:\FKOR\Spillovers"

capture log close
log using "Log\analysis-final.log", replace text

*********************************************
*********************************************
****** Table 1. Descriptive statistics ******
*********************************************
*********************************************

** column 1 **

scalar drop _all

use "Data\Temp\Jul21\demographics-ided-90-05.dta",  clear
keep if birthyear >= 1976 & birthyear <= 1996
keep id female eFRL white birthyear
foreach i in female eFRL white {
replace `i' = `i'*100
}
duplicates drop
su white 
scalar a1 = round(r(mean),0.1)
su eFRL
scalar a2 = round(r(mean),0.1)
su female
scalar a3 = round(r(mean),0.1)
su birthyear
scalar a4 = round(r(mean),0.1)

count
scalar a8 = r(N)

*** column 2 **

use "Data\Temp\Jul21\demographics-ided-90-05.dta",  clear
keep if birthyear >= 1976 & birthyear <= 1996
sort id testyear

merge m:1 id using "Data\Temp\Jul21\two-plus-families.dta"
keep if _merge == 3
drop _merge

keep id female eFRL white birthyear
foreach i in female eFRL white {
replace `i' = `i'*100
}
duplicates drop
su white 
scalar b1 = round(r(mean),0.1)
su eFRL
scalar b2 = round(r(mean),0.1)
su female
scalar b3 = round(r(mean),0.1)
su birthyear
scalar b4 = round(r(mean),0.1)

count
scalar b8 = r(N)

** column 3 **

use "Data\Temp\Jul21\demographics-ided-90-05.dta",  clear
keep if birthyear >= 1976 & birthyear <= 1996

merge m:1 id using "Data\Temp\Jul21\two-plus-families.dta"
keep if _merge == 3
drop _merge

merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
keep if _merge == 3
drop _merge

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep id female eFRL white birthyear
foreach i in female eFRL white {
replace `i' = `i'*100
}
duplicates drop
su white 
scalar c1 = round(r(mean),0.1)
su eFRL
scalar c2 = round(r(mean),0.1)
su female
scalar c3 = round(r(mean),0.1)
su birthyear
scalar c4 = round(r(mean),0.1)
count
scalar c8 = r(N)

use "Data\Temp\Jul21\demographics-ided-90-05.dta",  clear
keep if birthyear >= 1976 & birthyear <= 1996

merge m:1 id using "Data\Temp\Jul21\two-plus-families.dta"
keep if _merge == 3
drop _merge

merge 1:1 id testyear using "Data\Temp\Jul21\scores-math-read-90-05.dta"
keep if _merge == 3
drop _merge

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

gen disabled = (primex != "Z" & primex != "L")
gen gifted = (primex == "L")

foreach i in disabled gifted {
replace `i' = `i'*100
}

su scorep 
scalar c5 = round(r(mean),0.1)
su gifted
scalar c6 = round(r(mean),0.1)
su disabled
scalar c7 = round(r(mean),0.1)

** column 4 **

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

keep idY female eFRL white birthyear
foreach i in female eFRL white {
replace `i' = `i'*100
}
duplicates drop
su white 
scalar d1 = round(r(mean),0.1)
su eFRL
scalar d2 = round(r(mean),0.1)
su female
scalar d3 = round(r(mean),0.1)
su birthyear
scalar d4 = round(r(mean),0.1)
count
scalar d8 = r(N)

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

gen disabled = (primex != "Z" & primex != "L")
gen gifted = (primex == "L")

foreach i in disabled gifted {
replace `i' = `i'*100
}

su scorep 
scalar d5 = round(r(mean),0.1)
su gifted
scalar d6 = round(r(mean),0.1)
su disabled
scalar d7 = round(r(mean),0.1)

** column 5 **

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

keep idO female eFRL white birthyear
foreach i in female eFRL white {
replace `i' = `i'*100
}
duplicates drop
su white 
scalar e1 = round(r(mean),0.1)
su eFRL
scalar e2 = round(r(mean),0.1)
su female
scalar e3 = round(r(mean),0.1)
su birthyear
scalar e4 = round(r(mean),0.1)
count
scalar e8 = r(N)

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

gen disabled = (primex != "Z" & primex != "L")
gen gifted = (primex == "L")

foreach i in disabled gifted {
replace `i' = `i'*100
}

su scorep 
scalar e5 = round(r(mean),0.1)
su gifted
scalar e6 = round(r(mean),0.1)
su disabled
scalar e7 = round(r(mean),0.1)

** column 6 **

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

rename idY id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idY
keep if BO == 2

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

keep idY female eFRL white birthyear
foreach i in female eFRL white {
replace `i' = `i'*100
}
duplicates drop
su white 
scalar f1 = round(r(mean),0.1)
su eFRL
scalar f2 = round(r(mean),0.1)
su female
scalar f3 = round(r(mean),0.1)
su birthyear
scalar f4 = round(r(mean),0.1)
count
scalar f8 = r(N)

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

rename idY id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idY
keep if BO == 2

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

gen disabled = (primex != "Z" & primex != "L")
gen gifted = (primex == "L")

foreach i in disabled gifted {
replace `i' = `i'*100
}

su scorep 
scalar f5 = round(r(mean),0.1)
su gifted
scalar f6 = round(r(mean),0.1)
su disabled
scalar f7 = round(r(mean),0.1)

** column 7 **

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO
keep if BO == 1

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

keep idO female eFRL white birthyear
foreach i in female eFRL white {
replace `i' = `i'*100
}
duplicates drop
su white 
scalar g1 = round(r(mean),0.1)
su eFRL
scalar g2 = round(r(mean),0.1)
su female
scalar g3 = round(r(mean),0.1)
su birthyear
scalar g4 = round(r(mean),0.1)
count
scalar g8 = r(N)

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO
keep if BO == 1

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

gen disabled = (primex != "Z" & primex != "L")
gen gifted = (primex == "L")

foreach i in disabled gifted {
replace `i' = `i'*100
}

su scorep 
scalar g5 = round(r(mean),0.1)
su gifted
scalar g6 = round(r(mean),0.1)
su disabled
scalar g7 = round(r(mean),0.1)

matrix A = (a1\a2\a3\a4\.\.\.\a8)
matrix B = (b1\b2\b3\b4\.\.\.\b8)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8)
matrix G = (g1\g2\g3\g4\g5\g6\g7\g8)

matrix Z = (A,B,C,D,E,F,G)
mat list Z

*************************************************************************
*************************************************************************
********* Table 2. Discontinuities in background characteristics ********
*************************************************************************
*************************************************************************

** Older to younger **

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idY white black hispanic other female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

foreach i in white female eFRL {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg white trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2a.xls", nocons bdec(3) keep(trt) replace
reg female trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2a.xls", nocons bdec(3) keep(trt) append
reg birthmonth trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2a.xls", nocons bdec(3) keep(trt) append
reg birthyear trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2a.xls", nocons bdec(3) keep(trt) append
reg age_dif trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2a.xls", nocons bdec(3) keep(trt) append
reg eFRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2a.xls", nocons bdec(3) keep(trt) append

su white female birthmonth birthyear age_dif eFRL if birth_dif_sib >= -59 & birth_dif_sib <= 60

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)
 
destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

replace FRL = FRL*100

reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2a.xls", nocons bdec(3) keep(trt) append

su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60

** Younger to older **

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idO white black hispanic female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

foreach i in white female eFRL {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg white trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2b.xls", nocons bdec(3) keep(trt) replace
reg female trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2b.xls", nocons bdec(3) keep(trt) append
reg birthmonth trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2b.xls", nocons bdec(3) keep(trt) append
reg birthyear trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2b.xls", nocons bdec(3) keep(trt) append
reg age_dif trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2b.xls", nocons bdec(3) keep(trt) append
reg eFRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2b.xls", nocons bdec(3) keep(trt) append

su white female birthmonth birthyear age_dif eFRL if birth_dif_sib >= -59 & birth_dif_sib <= 60

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

replace FRL = FRL*100

reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t2b.xls", nocons bdec(3) keep(trt) append

su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60

**********************************************************************
**********************************************************************
****** Table 3. Main results: Sibling Spillovers in test scores ******
**********************************************************************
**********************************************************************

** Older to younger **

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) replace
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append
*
reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append
*
reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3a.xls", nocons bdec(3) keep(trt) append

su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

** Younger to older **

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) replace
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append
*
reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append
*
reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\t3b.xls", nocons bdec(3) keep(trt) append

su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

*******************************************************************************************************
*******************************************************************************************************
******* Figure 1. Distribution of sibling observations around focal child school-entry cutoff *********
*******************************************************************************************************
*******************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idY white black hispanic female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150
rddisttestk birth_dif_sib, threshold(0) k(0)
rddensity birth_dif_sib, c(0) p(1)

twoway (histogram birth_dif_sib, w(5) color(gray)), ylabel(0(0.001)0.005) ytick(0(0.0005)0.005) xlabel(-150 "-5" -120 "-4" -90 "-3" -60 "-2" -30 "-1" 0 "0" 30 "1" 60 "2" 90 "3" 120 "4" 150 "5") text(0.00475 25 "p-value: 0.552", size(small)) xline(0, lp(dash) lc(black) lw(thin)) xtitle("Months around threshold") ytitle("Density") graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-1A.tif", as(tif) replace

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idO white black hispanic female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150
rddisttestk birth_dif_sib, threshold(0) k(0)
rddensity birth_dif_sib, c(0) p(1)

twoway (histogram birth_dif_sib, w(5) color(gray)), ylabel(0(0.001)0.005) ytick(0(0.0005)0.005) xlabel(-150 "-5" -120 "-4" -90 "-3" -60 "-2" -30 "-1" 0 "0" 30 "1" 60 "2" 90 "3" 120 "4" 150 "5") text(0.00475 25 "p-value: 0.471", size(small)) xline(0, lp(dash) lc(black) lw(thin)) xtitle("Months around threshold") ytitle("Density") graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-1B.tif", as(tif) replace

********************************************************************************************************************************************************
********************************************************************************************************************************************************
******* Figure 2. Robustness of the main results: Older-to-younger spillovers in test scores among families ever on free or reduced price lunch *********
********************************************************************************************************************************************************
********************************************************************************************************************************************************

*** Panel A - badwidth selection and functional form ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

forvalues k = 20(5)150 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 1, cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib birth_dif_sib2 inter inter2 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
}


matrix X = (20\25\30\35\40\45\50\55\60\65\70\75\80\85\90\95\100\105\110\115\120\125\130\135\140\145\150)
matrix A = (a20\a25\a30\a35\a40\a45\a50\a55\a60\a65\a70\a75\a80\a85\a90\a95\a100\a105\a110\a115\a120\a125\a130\a135\a140\a145\a150)
matrix B = (b20\b25\b30\b35\b40\b45\b50\b55\b60\b65\b70\b75\b80\b85\b90\b95\b100\b105\b110\b115\b120\b125\b130\b135\b140\b145\b150)
matrix C = (c20\c25\c30\c35\c40\c45\c50\c55\c60\c65\c70\c75\c80\c85\c90\c95\c100\c105\c110\c115\c120\c125\c130\c135\c140\c145\c150)
matrix D = (d20\d25\d30\d35\d40\d45\d50\d55\d60\d65\d70\d75\d80\d85\d90\d95\d100\d105\d110\d115\d120\d125\d130\d135\d140\d145\d150)

matrix Z = (X,A,B,C,D)
svmat Z
keep Z1-Z5
keep in 1/27

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2

forvalues k = 1(1)2 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}


gen X1 = X-1
gen X2 = X+1

twoway (scatter E1 X1, msymbol(square) mcolor(gs0) msize(small)) (scatter E2 X2, msymbol(circle) mcolor(gs12) msize(small)) (rspike U1 L1 X1, lp(solid) lc(gs0) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(gs12) lw(thin)), ytitle("Older-to-younger spillovers in test scores" "for ever free or reduced price lunch families") xtitle("Bandwidth every 5 days (+/-)") xlabel(20(10)150) xtick(20(5)150) ylabel(-4(2)8) ytick(-4(1)8) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Local linear") label(2 "Quadratic") order(1 2) rows(1) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-2A.tif", as(tif) replace

*** B - donut regressions ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

keep if birth_dif_sib >= -59 & birth_dif_sib <= 60

forvalues k = 1(1)10 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)), cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (1\2\3\4\5\6\7\8\9\10)
matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/10

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E2 X, msymbol(circle) mcolor(gs0) msize(small)) (rspike U2 L2 X, lp(solid) lc(gs0) lw(thin)), ytitle("Older-to-younger spillovers in test scores" "for ever free or reduced price lunch families") xtitle("Dropping days around the threshold (+/-)") xlabel(1(1)10) ylabel(-1(1)8) ytick(-1(0.5)8) yline(0, lp(solid) lc(black) lw(thin)) legend(off) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-2B.tif", as(tif) replace

*** C - randomization test ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt0 = (birth_dif_sib > 0)
gen inter0 = trt0*birth_dif_sib

forvalues k = 1(1)100 {
gen birth_dif_sib_`k' = birth_dif_sib-`k'
gen birth_dif_sib`k' = birth_dif_sib+`k'

gen trt_`k'=(birth_dif_sib_`k'>0)
gen trt`k'=(birth_dif_sib`k'>0)

gen inter_`k'=trt_`k'*birth_dif_sib_`k'
gen inter`k'=trt`k'*birth_dif_sib`k'
}

reg scorep trt0 birth_dif_sib inter0 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar E0 = _b[trt0]
scalar F0 = _se[trt0]

forvalues k = 1(1)100 { 
reg scorep trt_`k' birth_dif_sib_`k' inter_`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib_`k' >= -59 & birth_dif_sib_`k' <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar e`k' = _b[trt_`k']
scalar f`k' = _se[trt_`k']
reg scorep trt`k' birth_dif_sib`k' inter`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib`k' >= -59 & birth_dif_sib`k' <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar g`k' = _b[trt`k']
scalar h`k' = _se[trt`k']
}

matrix X = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36\37\38\39\40\41\42\43\44\45\46\47\48\49\50\51\52\53\54\55\56\57\58\59\60\61\62\63\64\65\66\67\68\69\70\71\72\73\74\75\76\77\78\79\80\81\82\83\84\85\86\87\88\89\90\91\92\93\94\95\96\97\98\99\100)
matrix Y = X*(-1)

matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10\e11\e12\e13\e14\e15\e16\e17\e18\e19\e20\e21\e22\e23\e24\e25\e26\e27\e28\e29\e30\e31\e32\e33\e34\e35\e36\e37\e38\e39\e40\e41\e42\e43\e44\e45\e46\e47\e48\e49\e50\e51\e52\e53\e54\e55\e56\e57\e58\e59\e60\e61\e62\e63\e64\e65\e66\e67\e68\e69\e70\e71\e72\e73\e74\e75\e76\e77\e78\e79\e80\e81\e82\e83\e84\e85\e86\e87\e88\e89\e90\e91\e92\e93\e94\e95\e96\e97\e98\e99\e100)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10\f11\f12\f13\f14\f15\f16\f17\f18\f19\f20\f21\f22\f23\f24\f25\f26\f27\f28\f29\f30\f31\f32\f33\f34\f35\f36\f37\f38\f39\f40\f41\f42\f43\f44\f45\f46\f47\f48\f49\f50\f51\f52\f53\f54\f55\f56\f57\f58\f59\f60\f61\f62\f63\f64\f65\f66\f67\f68\f69\f70\f71\f72\f73\f74\f75\f76\f77\f78\f79\f80\f81\f82\f83\f84\f85\f86\f87\f88\f89\f90\f91\f92\f93\f94\f95\f96\f97\f98\f99\f100)

matrix G = (g1\g2\g3\g4\g5\g6\g7\g8\g9\g10\g11\g12\g13\g14\g15\g16\g17\g18\g19\g20\g21\g22\g23\g24\g25\g26\g27\g28\g29\g30\g31\g32\g33\g34\g35\g36\g37\g38\g39\g40\g41\g42\g43\g44\g45\g46\g47\g48\g49\g50\g51\g52\g53\g54\g55\g56\g57\g58\g59\g60\g61\g62\g63\g64\g65\g66\g67\g68\g69\g70\g71\g72\g73\g74\g75\g76\g77\g78\g79\g80\g81\g82\g83\g84\g85\g86\g87\g88\g89\g90\g91\g92\g93\g94\g95\g96\g97\g98\g99\g100)
matrix H = (h1\h2\h3\h4\h5\h6\h7\h8\h9\h10\h11\h12\h13\h14\h15\h16\h17\h18\h19\h20\h21\h22\h23\h24\h25\h26\h27\h28\h29\h30\h31\h32\h33\h34\h35\h36\h37\h38\h39\h40\h41\h42\h43\h44\h45\h46\h47\h48\h49\h50\h51\h52\h53\h54\h55\h56\h57\h58\h59\h60\h61\h62\h63\h64\h65\h66\h67\h68\h69\h70\h71\h72\h73\h74\h75\h76\h77\h78\h79\h80\h81\h82\h83\h84\h85\h86\h87\h88\h89\h90\h91\h92\h93\h94\h95\h96\h97\h98\h99\h100)

matrix Z1 = (Y\0\X)
matrix Z2 = (E\E0\G)

matrix V = (Z1,Z2)
svmat V
keep V1 V2
keep in 1/201

rename V1 X
rename V2 E1

twoway (kdensity E1, w(0.5) lp(solid) lc(gs0)), ylabel(0(0.05)0.25) xline(3.943, lp(dash) lc(gs0) lw(thick)) xlabel(-3(0.5)4) xtick(-3(0.25)4) xline(0, lp(solid) lc(black) lw(thin)) ytitle("Density") xtitle("Point estimates based on moving threshold by one day for +/- 100 days") legend(off) text(0.225 3 "RD estimate: 3.943", size(vsmall)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-2C.tif", as(tif) replace

*** D - sample restrictions ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

keep if coh_sib >= 1979
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idY id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idY

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

keep if BO == 2

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
drop if BO > 3
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar e1 = _b[trt]
scalar e2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idY)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idY)
egen temp3 = max(temp2), by(idY)
keep if temp3 >= 6
egen temp4 = seq(), by(idY)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar f1 = _b[trt]
scalar f2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idO id_sib
merge m:1 id_sib using "Data\Temp\Jul21\grade3score.dta"
keep if _merge == 3
drop _merge
rename id_sib idO

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar g1 = _b[trt]
scalar g2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idO id_sib
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs.dta"
keep if _merge == 3
drop _merge
rename id_sib idO

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar h1 = _b[trt]
scalar h2 = _se[trt]

matrix A = (a1\b1\c1\d1\e1\f1\g1\h1)
matrix B = (a2\b2\c2\d2\e2\f2\g2\h2)
matrix X = (1\3\5\7\9\11\13\15)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3
keep in 1/8
rename Z1 X
rename Z2 E
rename Z3 SE
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 3, color(gs0)) (bar E X if X == 5 | X == 7 | X == 9, color(gs5)) (bar E X if X == 11, color(gs10)) (bar E X if X == 13 | X == 15, color(gs15)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(1 "Baseline" 3 `" "September" "cutoff only" "' 5 `" "Fully" "observed" "' 7 `" "First two" "births" "'  9 `" "Parity one" "and two" "' 11 `" "Grades" "3 to 8" "' 13 `" "3rd grade" "scores" "' 15 `" "KG" "attendance" "', labsize(small)) xtitle("Sample restrictions") ytitle("Older-to-younger spillovers in test scores" "for ever free or reduced price lunch families") legend(label(1 "General") label(2 "Birth order related") label(3 "Panel analysis") label(4 "Focal child information related") order(1 2 3 4) rows(2) symx(*0.5) region(lc(none))) ylabel(0(2)8) ytick(-1(1)9) graphregion(fcolor(white) ifcolor(white) ilcolor(white))  
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-2D.tif", as(tif) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure 3. Robustness of the main results: Younger-to-older spillovers in test scores among families never on free or reduced price lunch *********
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

*** A - bandwidth selection and functional form ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

forvalues k = 20(5)150 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 0, cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib birth_dif_sib2 inter inter2 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 0, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
}


matrix X = (20\25\30\35\40\45\50\55\60\65\70\75\80\85\90\95\100\105\110\115\120\125\130\135\140\145\150)
matrix A = (a20\a25\a30\a35\a40\a45\a50\a55\a60\a65\a70\a75\a80\a85\a90\a95\a100\a105\a110\a115\a120\a125\a130\a135\a140\a145\a150)
matrix B = (b20\b25\b30\b35\b40\b45\b50\b55\b60\b65\b70\b75\b80\b85\b90\b95\b100\b105\b110\b115\b120\b125\b130\b135\b140\b145\b150)
matrix C = (c20\c25\c30\c35\c40\c45\c50\c55\c60\c65\c70\c75\c80\c85\c90\c95\c100\c105\c110\c115\c120\c125\c130\c135\c140\c145\c150)
matrix D = (d20\d25\d30\d35\d40\d45\d50\d55\d60\d65\d70\d75\d80\d85\d90\d95\d100\d105\d110\d115\d120\d125\d130\d135\d140\d145\d150)

matrix Z = (X,A,B,C,D)
svmat Z
keep Z1-Z5
keep in 1/27

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2

forvalues k = 1(1)2 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}


gen X1 = X-1
gen X2 = X+1

twoway (scatter E1 X1, msymbol(square) mcolor(gs0) msize(small)) (scatter E2 X2, msymbol(circle) mcolor(gs12) msize(small)) (rspike U1 L1 X1, lp(solid) lc(gs0) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(gs12) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for families never on free or reduced price lunch") xtitle("Bandwidth every 5 days (+/-)") xlabel(20(10)150) xtick(20(5)150) ylabel(-4(2)8) ytick(-5(1)8) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Local linear") label(2 "Quadratic") order(1 2) rows(1) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-3A.tif", as(tif) replace

*** B - donut regressions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

keep if birth_dif_sib >= -59 & birth_dif_sib <= 60

forvalues k = 1(1)10 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)), cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (1\2\3\4\5\6\7\8\9\10)
matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/10

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E3 X, msymbol(circle) mcolor(gs0) msize(small)) (rspike U3 L3 X, lp(solid) lc(gs0) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for families never on free or reduced price lunch") xtitle("Dropping days around the threshold (+/-)") xlabel(1(1)10) ylabel(-6(1)1) ytick(-6(0.5)1) yline(0, lp(solid) lc(black) lw(thin)) legend(off) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-3B.tif", as(tif) replace

*** C - randomization test ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt0 = (birth_dif_sib > 0)
gen inter0 = trt0*birth_dif_sib

forvalues k = 1(1)100 {
gen birth_dif_sib_`k' = birth_dif_sib-`k'
gen birth_dif_sib`k' = birth_dif_sib+`k'

gen trt_`k'=(birth_dif_sib_`k'>0)
gen trt`k'=(birth_dif_sib`k'>0)

gen inter_`k'=trt_`k'*birth_dif_sib_`k'
gen inter`k'=trt`k'*birth_dif_sib`k'
}

reg scorep trt0 birth_dif_sib inter0 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar I0 = _b[trt0]
scalar J0 = _se[trt0]

forvalues k = 1(1)100 { 
reg scorep trt_`k' birth_dif_sib_`k' inter_`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib_`k' >= -59 & birth_dif_sib_`k' <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar i`k' = _b[trt_`k']
scalar j`k' = _se[trt_`k']
reg scorep trt`k' birth_dif_sib`k' inter`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib`k' >= -59 & birth_dif_sib`k' <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar k`k' = _b[trt`k']
scalar l`k' = _se[trt`k']
}


matrix X = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36\37\38\39\40\41\42\43\44\45\46\47\48\49\50\51\52\53\54\55\56\57\58\59\60\61\62\63\64\65\66\67\68\69\70\71\72\73\74\75\76\77\78\79\80\81\82\83\84\85\86\87\88\89\90\91\92\93\94\95\96\97\98\99\100)
matrix Y = X*(-1)

matrix I = (i1\i2\i3\i4\i5\i6\i7\i8\i9\i10\i11\i12\i13\i14\i15\i16\i17\i18\i19\i20\i21\i22\i23\i24\i25\i26\i27\i28\i29\i30\i31\i32\i33\i34\i35\i36\i37\i38\i39\i40\i41\i42\i43\i44\i45\i46\i47\i48\i49\i50\i51\i52\i53\i54\i55\i56\i57\i58\i59\i60\i61\i62\i63\i64\i65\i66\i67\i68\i69\i70\i71\i72\i73\i74\i75\i76\i77\i78\i79\i80\i81\i82\i83\i84\i85\i86\i87\i88\i89\i90\i91\i92\i93\i94\i95\i96\i97\i98\i99\i100)
matrix J = (j1\j2\j3\j4\j5\j6\j7\j8\j9\j10\j11\j12\j13\j14\j15\j16\j17\j18\j19\j20\j21\j22\j23\j24\j25\j26\j27\j28\j29\j30\j31\j32\j33\j34\j35\j36\j37\j38\j39\j40\j41\j42\j43\j44\j45\j46\j47\j48\j49\j50\j51\j52\j53\j54\j55\j56\j57\j58\j59\j60\j61\j62\j63\j64\j65\j66\j67\j68\j69\j70\j71\j72\j73\j74\j75\j76\j77\j78\j79\j80\j81\j82\j83\j84\j85\j86\j87\j88\j89\j90\j91\j92\j93\j94\j95\j96\j97\j98\j99\j100)

matrix K = (k1\k2\k3\k4\k5\k6\k7\k8\k9\k10\k11\k12\k13\k14\k15\k16\k17\k18\k19\k20\k21\k22\k23\k24\k25\k26\k27\k28\k29\k30\k31\k32\k33\k34\k35\k36\k37\k38\k39\k40\k41\k42\k43\k44\k45\k46\k47\k48\k49\k50\k51\k52\k53\k54\k55\k56\k57\k58\k59\k60\k61\k62\k63\k64\k65\k66\k67\k68\k69\k70\k71\k72\k73\k74\k75\k76\k77\k78\k79\k80\k81\k82\k83\k84\k85\k86\k87\k88\k89\k90\k91\k92\k93\k94\k95\k96\k97\k98\k99\k100)
matrix L = (l1\l2\l3\l4\l5\l6\l7\l8\l9\l10\l11\l12\l13\l14\l15\l16\l17\l18\l19\l20\l21\l22\l23\l24\l25\l26\l27\l28\l29\l30\l31\l32\l33\l34\l35\l36\l37\l38\l39\l40\l41\l42\l43\l44\l45\l46\l47\l48\l49\l50\l51\l52\l53\l54\l55\l56\l57\l58\l59\l60\l61\l62\l63\l64\l65\l66\l67\l68\l69\l70\l71\l72\l73\l74\l75\l76\l77\l78\l79\l80\l81\l82\l83\l84\l85\l86\l87\l88\l89\l90\l91\l92\l93\l94\l95\l96\l97\l98\l99\l100)

matrix Z1 = (Y\0\X)
matrix Z2 = (I\I0\K)

matrix V = (Z1,Z2)
svmat V
keep V1 V2
keep in 1/201

rename V1 X
rename V2 E1

twoway (kdensity E1, w(0.5) lp(solid) lc(gs0)), ylabel(0(0.05)0.25)  xline(-1.773, lp(dash) lc(black) lw(thick)) xlabel(-3(0.5)3) xtick(-3(0.25)3) xline(0, lp(solid) lc(black) lw(thin)) ytitle("Density") xtitle("Point estimates based on moving threshold by one day for +/- 100 days") legend(off) text(0.22 -2.3 "RD estimate: -1.773", size(vsmall)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-3C.tif", as(tif) replace

*** D - sample restrictions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

keep if coh_sib >= 1979
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

keep if BO == 1

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
drop BO
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO
drop if BO > 2

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar e1 = _b[trt]
scalar e2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idO)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idO)
egen temp3 = max(temp2), by(idO)
keep if temp3 >= 6
egen temp4 = seq(), by(idO)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar f1 = _b[trt]
scalar f2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\grade3score.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar g1 = _b[trt]
scalar g2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar h1 = _b[trt]
scalar h2 = _se[trt]

matrix A = (a1\b1\c1\d1\e1\f1\g1\h1)
matrix B = (a2\b2\c2\d2\e2\f2\g2\h2)
matrix X = (1\3\5\7\9\11\13\15)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3
keep in 1/8
rename Z1 X
rename Z2 E
rename Z3 SE
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 3, color(gs0)) (bar E X if X == 5 | X == 7 | X == 9, color(gs5)) (bar E X if X == 11, color(gs10)) (bar E X if X == 13 | X == 15, color(gs15)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(1 "Baseline" 3 `" "September" "cutoff only" "' 5 `" "Fully" "observed" "' 7 `" "First two" "births" "' 9 `" "Parity one" "and two" "' 11 `" "Grades" "3 to 8" "' 13 `" "3rd grade" "scores" "' 15 `" "KG" "attendance" "', labsize(small)) xtitle("Sample restrictions") ytitle("Younger-to-older spillovers in test scores for" "families never on free or reduced price lunch") legend(label(1 "General") label(2 "Birth order related") label(3 "Panel analysis") label(4 "Focal child information related") order(1 2 3 4) rows(2)symx(*0.5) region(lc(none))) ylabel(-6(1)1) ytick(-6(0.5)1) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-3D.tif", as(tif) replace

*****************************************************************************************
*****************************************************************************************
*****************************************************************************************
*****************************************************************************************
*****************************************************************************************
********************** Online Appendix Content ******************************************
*****************************************************************************************
*****************************************************************************************
*****************************************************************************************
*****************************************************************************************
*****************************************************************************************

*****************************************************************************
*****************************************************************************
****** Table A1. School-entry Effects on Disability for Focal Children ******
*****************************************************************************
*****************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

keep idY idO female_sib white_sib coh_sib eFRL birth_dif_sib birthyear_sib
duplicates drop

rename idO id
merge 1:1 id using "Data\Temp\Jul21\disabilities-all.dta"
keep if _merge == 3
drop _merge
rename id idO

foreach i in edisab behav cognit physi otherd gifted {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg edisab trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1a.xls", nocons bdec(3) keep(trt) replace
reg behav trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1b.xls", nocons bdec(3) keep(trt) replace
reg cognit trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1c.xls", nocons bdec(3) keep(trt) replace
reg physi trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1d.xls", nocons bdec(3) keep(trt) replace
reg otherd trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1e.xls", nocons bdec(3) keep(trt) replace
reg gifted trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1f.xls", nocons bdec(3) keep(trt) replace 
*
reg edisab trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1a.xls", nocons bdec(3) keep(trt) append
reg behav trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1b.xls", nocons bdec(3) keep(trt) append
reg cognit trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1c.xls", nocons bdec(3) keep(trt) append
reg physi trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1d.xls", nocons bdec(3) keep(trt) append
reg otherd trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1e.xls", nocons bdec(3) keep(trt) append
reg gifted trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1f.xls", nocons bdec(3) keep(trt) append
*
reg edisab trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1a.xls", nocons bdec(3) keep(trt) append
reg behav trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1b.xls", nocons bdec(3) keep(trt) append
reg cognit trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1c.xls", nocons bdec(3) keep(trt) append
reg physi trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1d.xls", nocons bdec(3) keep(trt) append
reg otherd trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1e.xls", nocons bdec(3) keep(trt) append
reg gifted trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1f.xls", nocons bdec(3) keep(trt) append
*
su edisab behav cognit physi otherd gifted if (birth_dif_sib >= -59 & birth_dif_sib <= 60)
*
su edisab behav cognit physi otherd gifted if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1
*
su edisab behav cognit physi otherd gifted if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0
*

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

keep idY idO female_sib white_sib coh_sib eFRL birth_dif_sib birthyear_sib
duplicates drop

rename idY id
merge 1:1 id using "Data\Temp\Jul21\disabilities-all.dta"
keep if _merge == 3
drop _merge
rename id idY

foreach i in edisab behav cognit physi otherd gifted {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg edisab trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1a.xls", nocons bdec(3) keep(trt) append
reg behav trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1b.xls", nocons bdec(3) keep(trt) append
reg cognit trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1c.xls", nocons bdec(3) keep(trt) append
reg physi trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1d.xls", nocons bdec(3) keep(trt) append
reg otherd trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1e.xls", nocons bdec(3) keep(trt) append
reg gifted trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60), cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1f.xls", nocons bdec(3) keep(trt) append
*
reg edisab trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1a.xls", nocons bdec(3) keep(trt) append
reg behav trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1b.xls", nocons bdec(3) keep(trt) append
reg cognit trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1c.xls", nocons bdec(3) keep(trt) append
reg physi trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1d.xls", nocons bdec(3) keep(trt) append
reg otherd trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1e.xls", nocons bdec(3) keep(trt) append
reg gifted trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1f.xls", nocons bdec(3) keep(trt) append
*
reg edisab trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1a.xls", nocons bdec(3) keep(trt) append
reg behav trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1b.xls", nocons bdec(3) keep(trt) append
reg cognit trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1c.xls", nocons bdec(3) keep(trt) append
reg physi trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1d.xls", nocons bdec(3) keep(trt) append
reg otherd trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1e.xls", nocons bdec(3) keep(trt) append
reg gifted trt birth_dif_sib inter white_sib female_sib i.coh_sib if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0, cluster(birth_dif)
outreg2 using "Outreg\Jul21\tA1f.xls", nocons bdec(3) keep(trt) append
*
su edisab behav cognit physi otherd gifted if (birth_dif_sib >= -59 & birth_dif_sib <= 60)
*
su edisab behav cognit physi otherd gifted if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 1
*
su edisab behav cognit physi otherd gifted if (birth_dif_sib >= -59 & birth_dif_sib <= 60) & eFRL == 0

***********************************************************************************************
***********************************************************************************************
****** Table A2. Discontinuities in Background Characteristics. Non-parametric Estimates ******
***********************************************************************************************
***********************************************************************************************

** Older to younger **

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idY white black hispanic female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

foreach i in white female eFRL {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust white birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) replace
rdrobust female birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust birthmonth birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust birthyear birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust age_dif birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust eFRL birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

su white female birthmonth birthyear age_dif eFRL 

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .


foreach i in FRL RL {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust FRL birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

su FRL 

** Younger to older **

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idO white black hispanic female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

foreach i in white female eFRL  {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust white birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) replace
rdrobust female birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust birthmonth birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust birthyear birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust age_dif birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust eFRL birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

su white female birthmonth birthyear age_dif eFRL

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

foreach i in FRL RL  {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust FRL birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA2b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

su FRL 

************************************************************************************************************
************************************************************************************************************
****** Table A3. Discontinuities in Background Characteristics by Free and Reduced Price Lunch Status ******
************************************************************************************************************
************************************************************************************************************

** Older to younger **

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idY white black hispanic female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

foreach i in white female {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg white trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3a.xls", nocons bdec(3) keep(trt) replace
reg female trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3a.xls", nocons bdec(3) keep(trt) append
reg birthmonth trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3a.xls", nocons bdec(3) keep(trt) append
reg birthyear trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3a.xls", nocons bdec(3) keep(trt) append
reg age_dif trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3a.xls", nocons bdec(3) keep(trt) append
*
reg white trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3b.xls", nocons bdec(3) keep(trt) replace
reg female trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3b.xls", nocons bdec(3) keep(trt) append
reg birthmonth trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3b.xls", nocons bdec(3) keep(trt) append
reg birthyear trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3b.xls", nocons bdec(3) keep(trt) append
reg age_dif trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3b.xls", nocons bdec(3) keep(trt) append

su white female birthmonth birthyear age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su white female birthmonth birthyear age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)
 
destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

replace FRL = FRL*100

reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3a.xls", nocons bdec(3) keep(trt) append

su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1

** Younger to older **

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
keep if scorep != .

keep idO white black hispanic female birthmonth birthyear age_dif eFRL fFRL birth_dif_sib
duplicates drop

foreach i in white female {
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg white trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3c.xls", nocons bdec(3) keep(trt) replace
reg female trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3c.xls", nocons bdec(3) keep(trt) append
reg birthmonth trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3c.xls", nocons bdec(3) keep(trt) append
reg birthyear trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3c.xls", nocons bdec(3) keep(trt) append
reg age_dif trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3c.xls", nocons bdec(3) keep(trt) append
*
reg white trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3d.xls", nocons bdec(3) keep(trt) replace
reg female trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3d.xls", nocons bdec(3) keep(trt) append
reg birthmonth trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3d.xls", nocons bdec(3) keep(trt) append
reg birthyear trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3d.xls", nocons bdec(3) keep(trt) append
reg age_dif trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3d.xls", nocons bdec(3) keep(trt) append

su white female birthmonth birthyear age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su white female birthmonth birthyear age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

replace FRL = FRL*100

reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA3c.xls", nocons bdec(3) keep(trt) append

su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1

************************************************************************************************************
************************************************************************************************************
****** Table A4. Effects of Older Sibling School-entry Discontinuity on Subsequent Fertility ***************
************************************************************************************************************
************************************************************************************************************

use "Data\Temp\Jul21\demographics-ided-90-05.dta", clear
keep id famid birthyear birthmonth birthday dob female
duplicates drop

drop if famid == ""

keep if birthyear>=1979
drop if birthmonth <= 8 & birthyear == 1979
drop if birthyear >= 2001

egen temp2 = count(dob), by(famid birthyear birthmonth)
egen temp3 = max(temp2), by(famid)
drop if temp3 > 1

sort famid dob
egen BO = seq(), by(famid)
egen famsize = count(BO), by(famid)

gen cutoff1=""
forvalues i = 1978(1)2000 {
replace cutoff1="09-01-`i'" if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

drop if cutoff1==""
gen cutoff=date(cutoff1, "MDY")

gen birth_dif=dob-cutoff

gen coh=.
forvalues i = 1978(1)2000 {
replace coh=`i'+1 if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

keep id BO famsize famid birth_dif coh dob birthyear birthmonth female

drop if coh == 1980 | coh == 2001

egen temp1 = min(BO), by(famid)
keep if temp1 == 1
drop temp* birthyear birthmonth

reshape wide id birth_dif coh dob female, i(famid) j(BO)

merge 1:1 famid using "Data\Temp\Jul21\family-demographics.dta", keepusing(white eFRL fFRL)
keep if _merge == 3
drop _merge

forvalues i = 1(1)7 {
gen trt`i' = (birth_dif`i' > 0)
gen inter`i' = trt`i'*birth_dif`i'
}

forvalues k = 2(1)5 {
gen fert`k' = (dob`k' != .)
replace fert`k' = fert`k'*100
}

reg fert2 trt1 birth_dif1 inter1 i.coh1 if birth_dif1 >= -59 & birth_dif1 <= 60, cluster(birth_dif1)
outreg2 using "Outreg\Jul21\tA4.xls", nocons bdec(3) keep(trt1) replace
reg fert2 trt1 birth_dif1 inter1 i.coh1 female1 white fFRL if birth_dif1 >= -59 & birth_dif1 <= 60, cluster(birth_dif1)
outreg2 using "Outreg\Jul21\tA4.xls", nocons bdec(3) keep(trt1) append
*
reg fert3 trt2 birth_dif2 inter2 i.coh2 if birth_dif2 >= -59 & birth_dif2 <= 60 & dob2 != ., cluster(birth_dif2)
outreg2 using "Outreg\Jul21\tA4.xls", nocons bdec(3) keep(trt2) append
reg fert3 trt2 birth_dif2 inter2 i.coh2 female2 white fFRL if birth_dif2 >= -59 & birth_dif2 <= 60 & dob2 != ., cluster(birth_dif2)
outreg2 using "Outreg\Jul21\tA4.xls", nocons bdec(3) keep(trt2) append
*
reg fert4 trt3 birth_dif3 inter3 i.coh3 if birth_dif3 >= -59 & birth_dif3 <= 60 & dob2 != . & dob3 != ., cluster(birth_dif3)
outreg2 using "Outreg\Jul21\tA4.xls", nocons bdec(3) keep(trt3) append
reg fert4 trt3 birth_dif3 inter3 i.coh3 female3 white fFRL if birth_dif3 >= -59 & birth_dif3 <= 60 & dob3 != . & dob3 != ., cluster(birth_dif3)
outreg2 using "Outreg\Jul21\tA4.xls", nocons bdec(3) keep(trt3) append

su fert2 if birth_dif1 >= -59 & birth_dif1 <= 60
su fert3 if birth_dif2 >= -59 & birth_dif2 <= 60 & dob2 != .
su fert4 if birth_dif3 >= -59 & birth_dif3 <= 60 & dob2 != . & dob3 != .

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
****** Table A5. Proxies for Socioeconomic Staust of an Older Child Measured at Younger Child's School-entry Cutoff, Before and After the Younger Child Turns 5 **************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idY id_sib 
merge 1:1 id_sib testyear using "Data\Temp\Jul21\sibling-age5-timing.dta"
keep if _merge == 3
drop _merge
rename id_sib id_Y

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

replace FRL = FRL*100

drop if grade < 0 
drop if grade == 10

drop if timing == 1

egen temp1 = count(timing), by(idO)
keep if temp1 == 2

gen post1 = (timing == 0)

reg FRL trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == -1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5a.xls", nocons bdec(3) keep(trt) replace
reg FRL trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5b.xls", nocons bdec(3) keep(trt) replace

su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == -1
su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == 0

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idY id_sib 
merge 1:1 id_sib testyear using "Data\Temp\Jul21\sibling-age5-timing.dta"
keep if _merge == 3
drop _merge
rename id_sib id_Y

rename idO id

merge m:1 id testyear using "Data\Temp\Jul21\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idO

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

drop if grade < 0 
drop if grade == 10

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

drop if timing == 1

egen temp1 = count(timing), by(idO)
keep if temp1 == 2

gen post1 = (timing == 0)

reg neigh_inc trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == -1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5a.xls", nocons bdec(3) keep(trt) append
reg neigh_inc trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5b.xls", nocons bdec(3) keep(trt) append

reg neigh_hsd trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == -1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5a.xls", nocons bdec(3) keep(trt) append
reg neigh_hsd trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5b.xls", nocons bdec(3) keep(trt) append

reg neigh_colg trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == -1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5a.xls", nocons bdec(3) keep(trt) append
reg neigh_colg trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5b.xls", nocons bdec(3) keep(trt) append

reg neigh_singmom trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == -1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5a.xls", nocons bdec(3) keep(trt) append
reg neigh_singmom trt birth_dif_sib inter white female female_sib i.birthyear i.birthmonth i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA5b.xls", nocons bdec(3) keep(trt) append

su neigh_inc neigh_hsd neigh_colg neigh_singmom  if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == -1

su neigh_inc neigh_hsd neigh_colg neigh_singmom  if birth_dif_sib >= -59 & birth_dif_sib <= 60 & timing == 0

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
****** Table A6. Discontinuities in Background Characteristics: Neighborhod Characteristics and Annual FRPL ******************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

rename idY id

merge m:1 id testyear using "Data\Temp\Jul21\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idY

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)
 
destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_inc trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) replace
reg neigh_inc trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) replace 
reg neigh_inc trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) replace 

su neigh_inc if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_inc if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_inc if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Nov18\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idO id

merge m:1 id testyear using "Data\Temp\Nov18\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idO

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_inc trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg neigh_inc trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append
reg neigh_inc trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) append

su neigh_inc if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_inc if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_inc if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

rename idY id

merge m:1 id testyear using "Data\Temp\Jul21\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idY

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)
 
destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_hsd trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg neigh_hsd trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append
reg neigh_hsd trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) append

su neigh_hsd if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_hsd if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_hsd if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Nov18\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idO id

merge m:1 id testyear using "Data\Temp\Nov18\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idO

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_hsd trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg neigh_hsd trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append
reg neigh_hsd trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) append

su neigh_hsd if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_hsd if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_hsd if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

rename idY id

merge m:1 id testyear using "Data\Temp\Jul21\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idY

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)
 
destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_colg trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg neigh_colg trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append
reg neigh_colg trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) append

su neigh_colg if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_colg if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_colg if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Nov18\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idO id

merge m:1 id testyear using "Data\Temp\Nov18\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idO

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_colg trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg neigh_colg trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append
reg neigh_colg trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) append

su neigh_colg if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_colg if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_colg if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

rename idY id

merge m:1 id testyear using "Data\Temp\Jul21\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idY

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)
 
destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_singmom trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg neigh_singmom trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append
reg neigh_singmom trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) append

su neigh_singmom if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_singmom if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_singmom if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Nov18\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idO id

merge m:1 id testyear using "Data\Temp\Nov18\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idO

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg neigh_singmom trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg neigh_singmom trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append
reg neigh_singmom trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6c.xls", nocons bdec(3) keep(trt) append

su neigh_singmom if birth_dif_sib >= -59 & birth_dif_sib <= 60
su neigh_singmom if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su neigh_singmom if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

rename idY id

merge m:1 id testyear using "Data\Temp\Jul21\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idY

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)
 
destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append

su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60
su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1

use "Data\Temp\Nov18\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idO id

merge m:1 id testyear using "Data\Temp\Nov18\idiv-nighb-chars.dta"
keep if _merge == 3
drop _merge

rename id idO

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

ta grade, gen(gr)

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in neigh_hsd neigh_colg neigh_singmom FRL { 
replace `i' = `i'*100
}

reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6a.xls", nocons bdec(3) keep(trt) append
reg FRL trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA6b.xls", nocons bdec(3) keep(trt) append

su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60
su FRL if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
****** Table A7. Younger Sibling Compliance with School-entry Rules by Older Foocal Child School-entry Cutoff ****************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

keep idO idY birth_dif_sib white female birthyear birthmonth coh_sib female_sib age_dif eFRL
duplicates drop
rename idY id_sib 
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs-testyear.dta", keepusing(hb_sib ontime_sib early_sib pk_sib)
keep if _merge == 3
drop _merge

foreach i in hb ontime early pk {
rename `i'_sib `i'
replace `i' = `i'*100
}

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib


reg hb trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA7a.xls", nocons bdec(3) keep(trt) replace
reg early trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA7b.xls", nocons bdec(3) keep(trt) replace
reg ontime trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA7c.xls", nocons bdec(3) keep(trt) replace
* 
reg hb trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA7a.xls", nocons bdec(3) keep(trt) append
reg early trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib) 
outreg2 using "Outreg\Jul21\tA7b.xls", nocons bdec(3) keep(trt) append
reg ontime trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA7c.xls", nocons bdec(3) keep(trt) append
*
reg hb trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA7a.xls", nocons bdec(3) keep(trt) append
reg early trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)  
outreg2 using "Outreg\Jul21\tA7b.xls", nocons bdec(3) keep(trt) append
reg ontime trt birth_dif_sib inter white female i.birthyear i.birthmonth i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA7c.xls", nocons bdec(3) keep(trt) append

su hb early ontime if birth_dif_sib >= -59 & birth_dif_sib <= 60
su hb early ontime if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su hb early ontime if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
****** Table A8. Main Results: Estimates Separately for Reading and Math *****************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .
drop if mathp == .
drop if readp == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg mathp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mathp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8a.xls", nocons bdec(3) keep(trt) replace
reg readp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & readp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8b.xls", nocons bdec(3) keep(trt) replace
*
reg mathp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1 & mathp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8a.xls", nocons bdec(3) keep(trt) append
reg readp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1 & readp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8b.xls", nocons bdec(3) keep(trt) append
*
reg mathp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0 & mathp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8a.xls", nocons bdec(3) keep(trt) append
reg readp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0 & readp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8b.xls", nocons bdec(3) keep(trt) append

su mathp readp if birth_dif_sib >= -59 & birth_dif_sib <= 60
su mathp readp if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su mathp readp if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .
drop if mathp == .
drop if readp == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg mathp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mathp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8a.xls", nocons bdec(3) keep(trt) append
reg readp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & readp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8b.xls", nocons bdec(3) keep(trt) append
*
reg mathp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1 & mathp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8a.xls", nocons bdec(3) keep(trt) append
reg readp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1 & readp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8b.xls", nocons bdec(3) keep(trt) append
*
reg mathp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0 & mathp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8a.xls", nocons bdec(3) keep(trt) append
reg readp trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0 & readp !=., cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA8b.xls", nocons bdec(3) keep(trt) append

su mathp readp if birth_dif_sib >= -59 & birth_dif_sib <= 60
su mathp readp if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su mathp readp if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
****** Table A9. Effects of Younger Sibling School-entry Discontinuity on Older Child Achievement: Estimates by Timing of Testing ********************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 


gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

gen inter2 = (ngrade > 3)

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9a.xls", nocons bdec(3) keep(trt) replace
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade <= 3, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9a.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade > 3, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9a.xls", nocons bdec(3) keep(trt) append
xi:reg scorep i.inter2*trt i.inter2*birth_dif_sib i.inter2*inter i.inter2*white i.inter2*female i.inter2*i.grade i.inter2*i.birthyear i.inter2*i.birthmonth i.inter2*FCAT i.inter2*i.coh_sib i.inter2*female_sib i.inter2*age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)

su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade <= 3
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade > 3

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9b.xls", nocons bdec(3) keep(trt) replace
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1 & ngrade <= 3, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9b.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1 & ngrade > 3, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9b.xls", nocons bdec(3) keep(trt) append
xi:reg scorep i.inter2*trt i.inter2*birth_dif_sib i.inter2*inter i.inter2*white i.inter2*female i.inter2*i.grade i.inter2*i.birthyear i.inter2*i.birthmonth i.inter2*FCAT i.inter2*i.coh_sib i.inter2*female_sib i.inter2*age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)

su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade <= 3 & eFRL == 1
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade > 3 & eFRL == 1

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9c.xls", nocons bdec(3) keep(trt) replace
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0 & ngrade <= 3, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9c.xls", nocons bdec(3) keep(trt) append
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0 & ngrade > 3, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA9c.xls", nocons bdec(3) keep(trt) append
xi:reg scorep i.inter2*trt i.inter2*birth_dif_sib i.inter2*inter i.inter2*white i.inter2*female i.inter2*i.grade i.inter2*i.birthyear i.inter2*i.birthmonth i.inter2*FCAT i.inter2*i.coh_sib i.inter2*female_sib i.inter2*age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)

su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade <= 3 & eFRL == 0
su scorep if birth_dif_sib >= -59 & birth_dif_sib <= 60 & ngrade > 3 & eFRL == 0

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
****** Table A10. Main results: Sibling Spillovers in Test Scores: Non-parametric Estimates **********************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

ta grade, gen(gr)
ta birthyear, gen(by)
ta birthmonth, gen(bm)
ta coh_sib, gen(cs)

rdrobust scorep birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) replace
rdrobust scorep birth_dif_sib, c(0) p(1) covs(white female gr2-gr6 by2-by19 bm2-bm12 FCAT) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib, c(0) p(1) covs(white female gr2-gr6 by2-by19 bm2-bm12 FCAT cs2-cs20 female_sib age_dif) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1) covs(white female gr2-gr6 by2-by19 bm2-bm12 FCAT) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1) covs(white female gr2-gr6 by2-by19 bm2-bm12 FCAT cs2-cs20 female_sib age_dif) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) covs(white female gr2-gr6 by2-by19 bm2-bm12 FCAT) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) covs(white female gr2-gr6 by2-by19 bm2-bm12 FCAT cs2-cs20 female_sib age_dif) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10a.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

su scorep 
su scorep if eFRL == 1
su scorep if eFRL == 0

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

ta grade, gen(gr)
ta birthyear, gen(by)
ta birthmonth, gen(bm)
ta coh_sib, gen(cs)

rdrobust scorep birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) replace
rdrobust scorep birth_dif_sib, c(0) p(1) covs(white female gr2-gr6 by2-by18 bm2-bm12 FCAT) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib, c(0) p(1) covs(white female gr2-gr6 by2-by18 bm2-bm12 FCAT cs2-cs19 female_sib age_dif) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1) covs(white female gr2-gr6 by2-by18 bm2-bm12 FCAT) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1) covs(white female gr2-gr6 by2-by18 bm2-bm12 FCAT cs2-cs19 female_sib age_dif) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) covs(white female gr2-gr6 by2-by18 bm2-bm12 FCAT) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) covs(white female gr2-gr6 by2-by18 bm2-bm12 FCAT cs2-cs19 female_sib age_dif) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA10b.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

su scorep 
su scorep if eFRL == 1
su scorep if eFRL == 0

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
****** Table A11. Main Results with 95% Confidence Intervals: Testing Various Standard Errors Assumptions ********************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************

*** Robust SE ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, robust
outreg2 using "Outreg\Jul21\tA11a.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) replace
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, robust
outreg2 using "Outreg\Jul21\tA11a.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, robust
outreg2 using "Outreg\Jul21\tA11a.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib
reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, robust
outreg2 using "Outreg\Jul21\tA11a.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, robust
outreg2 using "Outreg\Jul21\tA11a.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, robust
outreg2 using "Outreg\Jul21\tA11a.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append

*** Cluster RV ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11b.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) replace
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11b.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11b.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib
reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11b.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11b.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11b.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append

*** Cluster at family level **

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(famid)
outreg2 using "Outreg\Jul21\tA11c.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) replace
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(famid)
outreg2 using "Outreg\Jul21\tA11c.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(famid)
outreg2 using "Outreg\Jul21\tA11c.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib
reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(famid)
outreg2 using "Outreg\Jul21\tA11c.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(famid)
outreg2 using "Outreg\Jul21\tA11c.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(famid)
outreg2 using "Outreg\Jul21\tA11c.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append

*** Cluster two-way at RV and family level ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

cluster2 scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, fcluster(birth_dif_sib) tcluster(famid)
outreg2 using "Outreg\Jul21\tA11d.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) replace
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

cluster2 scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, fcluster(birth_dif_sib) tcluster(famid)
outreg2 using "Outreg\Jul21\tA11d.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

cluster2 scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, fcluster(birth_dif_sib) tcluster(famid)
outreg2 using "Outreg\Jul21\tA11d.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

cluster2 scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, fcluster(birth_dif_sib) tcluster(famid)
outreg2 using "Outreg\Jul21\tA11d.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

cluster2 scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, fcluster(birth_dif_sib) tcluster(famid)
outreg2 using "Outreg\Jul21\tA11d.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

cluster2 scorep trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, fcluster(birth_dif_sib) tcluster(famid)
outreg2 using "Outreg\Jul21\tA11d.xls", nocons bdec(3) stats(coef se ci_low ci_high) keep(trt) append


**** Non-parametric estimates clusted RV ****

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11e.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) replace
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib, c(0) p(1) vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11e.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1)  vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11e.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1)  vce(cluster birth_dif_sib)
outreg2 using "Outreg\Jul21\tA11e.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) vce(cluster birth_dif_sib) 
outreg2 using "Outreg\Jul21\tA11e.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) vce(cluster birth_dif_sib) 
outreg2 using "Outreg\Jul21\tA11e.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

**** Non-paramentric estimates nearest neighbor ****

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib, c(0) p(1) vce(nn)
outreg2 using "Outreg\Jul21\tA11f.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) replace
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib, c(0) p(1) vce(nn)
outreg2 using "Outreg\Jul21\tA11f.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1)  vce(nn)
outreg2 using "Outreg\Jul21\tA11f.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 1, c(0) p(1)  vce(nn)
outreg2 using "Outreg\Jul21\tA11f.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) vce(nn) 
outreg2 using "Outreg\Jul21\tA11f.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append
*
use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rdrobust scorep birth_dif_sib if eFRL == 0, c(0) p(1) vce(nn) 
outreg2 using "Outreg\Jul21\tA11f.xls", addstat(Robust Est., e(tau_bc), Robust SE, e(se_tau_rb), Robust p-v., e(pv_rb), BW Loc. Poly., e(h_r)) nose noaster nonotes adec(3) append

*** Please see the separate R code for the Kolesar and Rothe (2018) and Armstrong and Kolesar (2020) estimation ***

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A1. Persistance of school-entry cutoff advantage: Focal children effects over grades ******************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\sibling-sample-as-singletons.dta", clear
drop if grade == "PK" | grade == "KG"
destring grade, replace
egen scorep = rowmean(mathp readp)
drop if scorep == .
keep if grade >= 3 & grade <= 8
sort id testyear
egen period = seq(), by(id) 
egen inpanel = max(period), by(id)
replace period = period + 2

gen trt = (birth_dif > 0)
gen inter = trt*birth_dif

forvalues k = 3(1)8 {
reg scorep trt birth_dif inter i.coh if period == `k' & inpanel >= 6 & (birth_dif >= -59 & birth_dif <= 60), cluster(birth_dif)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif inter i.coh if period == `k' & inpanel >= 6 & (birth_dif >= -59 & birth_dif <= 60) & eFRL == 1, cluster(birth_dif)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif inter i.coh if period == `k' & inpanel >= 6 & (birth_dif >= -59 & birth_dif <= 60) & eFRL == 0, cluster(birth_dif)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}

matrix X = (3\4\5\6\7\8)
matrix A = (a3\a4\a5\a6\a7\a8)
matrix B = (b3\b4\b5\b6\b7\b8)
matrix C = (c3\c4\c5\c6\c7\c8)
matrix D = (d3\d4\d5\d6\d7\d8)
matrix E = (e3\e4\e5\e6\e7\e8)
matrix F = (f3\f4\f5\f6\f7\f8)

matrix Z = (X,A,B,C,D,E,F)
svmat Z

keep Z1 Z2 Z3 Z4 Z5 Z6 Z7
keep in 1/6

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues i = 1(1)3 {
gen U`i' = E`i'+1.96*SE`i'
gen L`i' = E`i'-1.96*SE`i'
}

gen X1 = X-0.1
gen X3 = X+0.1
rename X X2

twoway (scatter E1 X1, msymbol(triangle) mcolor(maroon)) (scatter E2 X2, msymbol(square) mcolor(navy)) (scatter E3 X3, msymbol(circle) mcolor(dkorange))  (rspike U1 L1 X1, lp(solid) lc(maroon) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(navy) lw(thin)) (rspike U3 L3 X3, lp(solid) lc(dkorange) lw(thin)), ylabel(0(2)10) ytick(0(1)11) xlabel(3(1)8) xtitle("Grades") ytitle("Child born after school entry cutoff" "Test scores (national percentiles)") legend(label(1 "Full sample") label(2 "Ever on FRPL") label(3 "Never on FRPL") order(1 2 3) rows(1) region(lc(none))) yline(5.461, lp(solid) lc(maroon)) yline(6.562, lp(dash) lc(navy)) yline(5.394, lp("-....-") lc(dkorange)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A1.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A2. Discontinuity in age at school-entry **************************************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\demographics90-05.dta", clear
merge m:1 id using "Data\Temp\Jul21\identifiers.dta"
keep if _merge == 3
drop _merge

merge m:1 famid using "Data\Temp\Jul21\family-demographics.dta"
keep if _merge == 3
drop _merge

drop if grade == "PK"
replace grade = "00" if grade == "KG"
destring grade, replace
keep if grade == 0 

keep if birthyear>=1973 & birthyear<=2000

egen temp1 = min(testyear), by(id)
keep if temp1 == testyear

gen ssd = mdy(9,1,testyear-1)
format ssd %td

gen age = ssd-dob

gen age2 = age/365

drop if age2 < 4
drop if age2 > 8
drop age2

gen cutoff1=""
forvalues i = 1970(1)1974{
replace cutoff1="01-01-`i'" if (birthyear==`i'-1 & birthmonth>6) | (birthyear==`i' & birthmonth<=6)
}
replace cutoff1="01-01-1975" if (birthyear==1974 & birthmonth>6) | (birthyear==1975 & birthmonth<6)

replace cutoff1="12-01-1975" if (birthyear==1975 & birthmonth>5) | (birthyear==1976 & birthmonth<5)
replace cutoff1="11-01-1976" if (birthyear==1976 & birthmonth>4) | (birthyear==1977 & birthmonth<4)
replace cutoff1="10-01-1977" if (birthyear==1977 & birthmonth>3) | (birthyear==1978 & birthmonth<3)
forvalues i = 1978(1)2000 {
replace cutoff1="09-01-`i'" if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

drop if cutoff1==""
gen cutoff=date(cutoff1, "MDY")

gen birth_dif=dob-cutoff

drop if birthyear <= 1983 & birthyear >= 2000

egen nid = group(id)
keep if birth_dif >= -149 & birth_dif <= 150

gen age2 = age/365

gen trt = (birth_dif > 0)
gen inter = trt*birth_dif

reg age2 trt birth_dif inter if birth_dif >= -59 & birth_dif <= 60, cluster(birth_dif)


keep nid birth_dif age 

collapse (count) nid (mean) age, by(birth_dif)

replace age = age/365
rename nid id

twoway (scatter age birth_dif [w = id], msymbol(circle) mcolor(black) msize(tiny)) (lfit age birth_dif [w=id] if birth_dif >= -59 & birth_dif <= 0, lc(black) lp(solid) lw(thick)) (lfit age birth_dif [w=id] if birth_dif > 0 & birth_dif <= 60, lc(black) lp(solid) lw(thick)), xlabel(-150(30)150) xtick(-150(15)150) xline(0, lc(black) lp(dash) lw(thin)) ytitle("Age in years at the start of kindergarten") xtitle("Days around school entry cutoff") legend(label(1 "Within bin mean") label(2 "Local linear fit") order(1 2) rows(1) region(lc(none))) ylabel(5(0.2)6) ytick(5(0.1)6) text(5.5 40 "Difference = 0.87") graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A2a.pdf", as(pdf) replace

use "Data\Temp\Jul21\demographics90-05.dta", clear
merge m:1 id using "Data\Temp\Jul21\identifiers.dta"
keep if _merge == 3
drop _merge

merge m:1 famid using "Data\Temp\Jul21\family-demographics.dta"
keep if _merge == 3
drop _merge

drop if grade == "PK"
replace grade = "00" if grade == "KG"
destring grade, replace
keep if grade == 0 

keep if birthyear>=1973 & birthyear<=2000

egen temp1 = min(testyear), by(id)
keep if temp1 == testyear

gen ssd = mdy(9,1,testyear-1)
format ssd %td

gen age = ssd-dob

gen age2 = age/365

drop if age2 < 4
drop if age2 > 8
drop age2

gen cutoff1=""
forvalues i = 1970(1)1974{
replace cutoff1="01-01-`i'" if (birthyear==`i'-1 & birthmonth>6) | (birthyear==`i' & birthmonth<=6)
}
replace cutoff1="01-01-1975" if (birthyear==1974 & birthmonth>6) | (birthyear==1975 & birthmonth<6)

replace cutoff1="12-01-1975" if (birthyear==1975 & birthmonth>5) | (birthyear==1976 & birthmonth<5)
replace cutoff1="11-01-1976" if (birthyear==1976 & birthmonth>4) | (birthyear==1977 & birthmonth<4)
replace cutoff1="10-01-1977" if (birthyear==1977 & birthmonth>3) | (birthyear==1978 & birthmonth<3)
forvalues i = 1978(1)2000 {
replace cutoff1="09-01-`i'" if (birthyear==`i' & birthmonth>2) | (birthyear==`i'+1 & birthmonth<=2)
}

drop if cutoff1==""
gen cutoff=date(cutoff1, "MDY")

gen birth_dif=dob-cutoff

drop if birthyear <= 1983 & birthyear >= 2000

egen nid = group(id)
keep if birth_dif >= -149 & birth_dif <= 150

gen age2 = age/365

gen trt = (birth_dif > 0)
gen inter = trt*birth_dif

reg age2 trt birth_dif inter if birth_dif >= -59 & birth_dif <= 60 & eFRL == 1, cluster(birth_dif)
reg age2 trt birth_dif inter if birth_dif >= -59 & birth_dif <= 60 & eFRL == 0, cluster(birth_dif)

keep nid birth_dif age eFRL

collapse (count) nid (mean) age, by(birth_dif eFRL)

replace age = age/365
rename nid id

twoway (scatter age birth_dif [w = id] if eFRL == 1, msymbol(circle) mcolor(navy) msize(tiny)) (lfit age birth_dif [w=id] if birth_dif >= -59 & birth_dif <= 0 & eFRL == 1, lc(navy) lp(solid) lw(thick)) (lfit age birth_dif [w=id] if birth_dif > 0 & birth_dif <= 60 & eFRL == 1, lc(navy) lp(solid) lw(thick)) (scatter age birth_dif [w = id] if eFRL == 0, msymbol(circle) mcolor(dkorange) msize(tiny)) (lfit age birth_dif [w=id] if birth_dif >= -59 & birth_dif <= 0 & eFRL == 0, lc(dkorange) lp(solid) lw(thick)) (lfit age birth_dif [w=id] if birth_dif > 0 & birth_dif <= 60 & eFRL == 0, lc(dkorange) lp(solid) lw(thick)), xlabel(-150(30)150) xtick(-150(15)150) xline(0, lc(black) lp(dash) lw(thin)) ytitle("Age in years at the start of kindergarten") xtitle("Days around school entry cutoff") legend(label(2 "Ever") label(5 "Never") order(- "Free or reduced price lunch:" 2 5) rows(1) region(lc(none))) ylabel(5(0.2)6) ytick(5(0.1)6) text(5.53 40 "Difference = 0.90", color(navy)) text(5.47 40 "Difference = 0.82", color(dkorange)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A2b.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A3. Free or reduced price lunch status of an older child as a function of younger child's school entry age ********************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idY id_sib 
merge 1:1 id_sib testyear using "Data\Temp\Jul21\sibling-age5-timing-v2.dta"
keep if _merge == 3
drop _merge
rename id_sib id_Y

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

replace FRL = FRL*100

egen temp1 = count(timing), by(idO)
keep if temp1 == 6

ta timing, gen(p)

forvalues k = 1(1)6 {
gen ptrt`k' = p`k'*trt
gen pbirth_dif_sib`k' = p`k'*birth_dif_sib
gen pinter`k' = p`k'*inter
}

reg FRL ptrt1 ptrt2 ptrt4 ptrt5 ptrt6 pbirth_dif_sib1 pbirth_dif_sib2 pbirth_dif_sib4 pbirth_dif_sib5 pbirth_dif_sib6 pinter1 pinter2 pinter4 pinter5 pinter6 p1 p2 p4 p5 p6 trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
forvalues k = 1(1)2 {
scalar a`k' = _b[ptrt`k']
scalar b`k' = _se[ptrt`k']
}

forvalues k = 4(1)6 {
scalar a`k' = _b[ptrt`k']
scalar b`k' = _se[ptrt`k']
}

forvalues k = 1(1)6 {
su FRL if p`k' == 1 & birth_dif_sib >= -59 & birth_dif_sib <= 60
scalar c`k' = r(mean)
}

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

rename idY id_sib 
merge 1:1 id_sib testyear using "Data\Temp\Jul21\sibling-age5-timing-v2.dta"
keep if _merge == 3
drop _merge
rename id_sib id_Y

replace grade = "-01" if grade == "PK"
replace grade = "00" if grade == "KG"

destring grade, replace

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

replace FRL = FRL*100

drop if timing == 2

egen temp1 = count(timing), by(idO)
keep if temp1 == 5

ta timing, gen(p)

forvalues k = 1(1)5 {
gen ptrt`k' = p`k'*trt
gen pbirth_dif_sib`k' = p`k'*birth_dif_sib
gen pinter`k' = p`k'*inter
}

reg FRL ptrt1 ptrt2 ptrt4 ptrt5 pbirth_dif_sib1 pbirth_dif_sib2 pbirth_dif_sib4 pbirth_dif_sib5 pinter1 pinter2 pinter4 pinter5 p1 p2 p4 p5 trt birth_dif_sib inter if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
foreach k in 1 2 4 5 {
scalar d`k' = _b[ptrt`k']
scalar e`k' = _se[ptrt`k']
}

forvalues k = 1(1)5 {
su FRL if p`k' == 1 & birth_dif_sib >= -59 & birth_dif_sib <= 60
scalar f`k' = r(mean)
}

matrix X = (-3\-2\-1\0\1\2)

matrix A = (a1\a2\0\a4\a5\a6)
matrix B = (b1\b2\0\b4\b5\b6)
matrix C = (c1\c2\c3\c4\c5\c6)

matrix D = (d1\d2\0\d4\d5\.)
matrix E = (e1\e2\0\e4\e5\.)
matrix F = (f1\f2\f3\f4\f5\.)

matrix Z = (X,A,B,C,D,E,F)
svmat Z

keep Z1-Z7
keep in 1/6

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 M1
rename Z5 E2
rename Z6 SE2
rename Z7 M2

foreach i in 1 2 {
replace E`i' = (E`i'/M`i')*100
replace SE`i' = (SE`i'/M`i')*100
gen L`i' = E`i'-1.96*SE`i'
gen U`i' = E`i'+1.96*SE`i'
}

gen X1 = X-0.1
gen X2 = X+0.1

twoway (scatter E1 X1, msymbol(square) mcolor(dkorange)) (scatter E2 X2, msymbol(circle) mcolor(navy)) (rspike L1 U1 X1, lp(solid) lc(dkorange)) (rspike L2 U2 X2, lp(solid) lc(navy)), ylabel(-20(5)20) xscale(r(-3.5 2.5)) xlabel(-3 "Three before" -2 "Two before" -1 "One before" 0 "Age 5 year" 1 "One after" 2 "Two after", labsize(small) notick) xtitle("Years relative to when younger child turns 5") legend(label(1 "6-years") label(2 "5-years") order(- "Panel:" 1 2) rows(1) region(lc(none))) ytitle("Free or reduced price lunch" "(scaled by period mean; % effect)") graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A3.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A4. Sibling spillovers over grades ********************************************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idY)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idY)
egen temp3 = max(temp2), by(idY)
keep if temp3 >= 6
egen temp4 = seq(), by(idY)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

forvalues k = 3(1)8 {
reg scorep trt birth_dif_sib inter white female i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & igrade == `k', cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & igrade == `k' & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & igrade == `k' & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (3\4\5\6\7\8)
matrix A = (a3\a4\a5\a6\a7\a8)
matrix B = (b3\b4\b5\b6\b7\b8)
matrix C = (c3\c4\c5\c6\c7\c8)
matrix D = (d3\d4\d5\d6\d7\d8)
matrix E = (e3\e4\e5\e6\e7\e8)
matrix F = (f3\f4\f5\f6\f7\f8)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/6

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E2 X2, msymbol(square) mcolor(dkorange) msize(small))  (scatter E3 X3, msymbol(circle) mcolor(navy) msize(small)) (rspike U2 L2 X2, lp(solid) lc(dkorange) lw(thin)) (rspike U3 L3 X3, lp(solid) lc(navy) lw(thin)), ytitle("Older-to-younger spillovers in test scores") xtitle("Grades") xlabel(3(1)8) ylabel(-8(2)10) ytick(-8(1)10) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Ever") label(2 "Never") order(- "Free or reduced price lunch:" 1 2) rows(1) symx(*0.5) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A4a.pdf", as(pdf) replace

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idO)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idO)
egen temp3 = max(temp2), by(idO)
keep if temp3 >= 6
egen temp4 = seq(), by(idO)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

forvalues k = 3(1)8 {
reg scorep trt birth_dif_sib inter white female i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & igrade == `k', cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & igrade == `k' & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & igrade == `k' & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (3\4\5\6\7\8)
matrix A = (a3\a4\a5\a6\a7\a8)
matrix B = (b3\b4\b5\b6\b7\b8)
matrix C = (c3\c4\c5\c6\c7\c8)
matrix D = (d3\d4\d5\d6\d7\d8)
matrix E = (e3\e4\e5\e6\e7\e8)
matrix F = (f3\f4\f5\f6\f7\f8)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/6

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E2 X2, msymbol(square) mcolor(dkorange) msize(small))  (scatter E3 X3, msymbol(circle) mcolor(navy) msize(small)) (rspike U2 L2 X2, lp(solid) lc(dkorange) lw(thin)) (rspike U3 L3 X3, lp(solid) lc(navy) lw(thin)), ytitle("Younger-to-older spillovers in test scores") xtitle("Grades") xlabel(3(1)8) ylabel(-8(2)10) ytick(-8(1)10) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Ever") label(2 "Never") order(- "Free or reduced price lunch:" 1 2) rows(1) symx(*0.5) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A4b.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A5. Discontinuities in test scores ********************************************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

keep idY testyear scorep  birth_dif_sib
egen id = group(idY)

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

collapse (count) id (mean) scorep, by(birth_dif_sib) 

twoway (scatter scorep birth_dif_sib [w=id], msymbol(circle) mcolor(black) msize(tiny)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib >= -59 & birth_dif_sib <= 0, lc(black) lp(solid) lw(thick)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib > 0 & birth_dif_sib <= 60, lc(black) lp(solid) lw(thick)), xlabel(-150(30)150) xtick(-150(15)150) xline(0, lc(black) lp(dash) lw(thin)) ytitle("Test scores") xtitle("Days around older sibling SSA cutoff") legend(label(1 "Within bin mean") label(2 "Local linear fit") order(1 2) rows(1) region(lc(none))) ylabel(55(5)70) ytick(52.5(2.5)72.5) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A5a.pdf", as(pdf) replace

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

keep idY testyear scorep  birth_dif_sib eFRL
egen id = group(idY)

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

collapse (count) id (mean) scorep, by(birth_dif_sib eFRL) 

twoway (scatter scorep birth_dif_sib [w=id] if eFRL == 1, msymbol(circle) mcolor(navy) msize(tiny)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib >= -59 & birth_dif_sib <= 0 & eFRL == 1, lc(navy) lp(solid) lw(thick)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib > 0 & birth_dif_sib <= 60 & eFRL == 1, lc(navy) lp(solid) lw(thick)) (scatter scorep birth_dif_sib [w=id] if eFRL == 0, msymbol(square) mcolor(dkorange) msize(tiny)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib >= -59 & birth_dif_sib <= 0 & eFRL == 0, lc(dkorange) lp(solid) lw(thick)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib > 0 & birth_dif_sib <= 60 & eFRL == 0, lc(dkorange) lp(solid) lw(thick)), xlabel(-150(30)150) xtick(-150(15)150) xline(0, lc(black) lp(dash) lw(thin)) ytitle("Test scores") xtitle("Days around older sibling SSA cutoff") legend(label(2 "Ever on FRPL") label(5 "Never on FRPL") order(2 5) rows(1) symx(*0.5) region(lc(none))) ylabel(40(5)80) ytick(37.5(2.5)82.5) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A5b.pdf", as(pdf) replace

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

keep idO testyear scorep  birth_dif_sib
egen id = group(idO)

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

collapse (count) id (mean) scorep, by(birth_dif_sib) 

twoway (scatter scorep birth_dif_sib [w=id], msymbol(circle) mcolor(black) msize(tiny)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib >= -59 & birth_dif_sib <= 0, lc(black) lp(solid) lw(thick)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib > 0 & birth_dif_sib <= 60, lc(black) lp(solid) lw(thick)), xlabel(-150(30)150) xtick(-150(15)150) xline(0, lc(black) lp(dash) lw(thin)) ytitle("Test scores") xtitle("Days around younger sibling SSA cutoff") legend(label(1 "Within bin mean") label(2 "Local linear fit") order(1 2) rows(1) region(lc(none))) ylabel(55(5)70) ytick(52.5(2.5)72.5) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A5c.pdf", as(pdf) replace

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

keep idO testyear scorep  birth_dif_sib eFRL
egen id = group(idO)

keep if birth_dif_sib >= -149 & birth_dif_sib <= 150

collapse (count) id (mean) scorep, by(birth_dif_sib eFRL) 

twoway (scatter scorep birth_dif_sib [w=id] if eFRL == 1, msymbol(circle) mcolor(navy) msize(tiny)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib >= -59 & birth_dif_sib <= 0 & eFRL == 1, lc(navy) lp(solid) lw(thick)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib > 0 & birth_dif_sib <= 60 & eFRL == 1, lc(navy) lp(solid) lw(thick)) (scatter scorep birth_dif_sib [w=id] if eFRL == 0, msymbol(square) mcolor(dkorange) msize(tiny)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib >= -59 & birth_dif_sib <= 0 & eFRL == 0, lc(dkorange) lp(solid) lw(thick)) (lfit scorep birth_dif_sib [w=id] if birth_dif_sib > 0 & birth_dif_sib <= 60 & eFRL == 0, lc(dkorange) lp(solid) lw(thick)), xlabel(-150(30)150) xtick(-150(15)150) xline(0, lc(black) lp(dash) lw(thin)) ytitle("Test scores") xtitle("Days around younger sibling SSA cutoff") legend(label(2 "Ever on FRPL") label(5 "Never on FRPL") order(2 5) rows(1) symx(*0.5) region(lc(none))) ylabel(40(5)80) ytick(37.5(2.5)82.5) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A5d.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A6. Heterogeneity analysis by gender composition of sibling pair **************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen MM = (female == 0 & female_sib == 0)
gen FF = (female == 1 & female_sib == 1)
gen MF = (female == 1 & female_sib == 0)
gen FM = (female == 0 & female_sib == 1)

gen SS = (MM == 1 | FF == 1)
gen OS = (MF == 1 | FM == 1) 

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & SS == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & OS == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & SS == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & OS == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen MM = (female == 0 & female_sib == 0)
gen FF = (female == 1 & female_sib == 1)
gen MF = (female == 0 & female_sib == 1)
gen FM = (female == 1 & female_sib == 0)

gen SS = (MM == 1 | FF == 1)
gen OS = (MF == 1 | FM == 1) 

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & SS == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a3 = _b[trt]
scalar a4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & OS == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar b3 = _b[trt]
scalar b4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & SS == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c3 = _b[trt]
scalar c4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & OS == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar d3 = _b[trt]
scalar d4 = _se[trt]

matrix X = (1\2\4\5\7\8\10\11)
matrix A = (a1\b1\c1\d1\a3\b3\c3\d3)
matrix B = (a2\b2\c2\d2\a4\b4\c4\d4)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3

keep in 1/8

rename Z1 X
rename Z2 E
rename Z3 SE

gen L = E-1.96*SE
gen U = E+1.96*SE

twoway (bar E X if X == 1 | X == 7, color(navy) fi(100)) (bar E X if X == 4 | X == 10, color(navy) fi(50)) (bar E X if X == 2 | X == 8, color(maroon) fi(100)) (bar E X if X == 5 | X == 11, color(maroon) fi(50)) (rspike L U X, lp(solid) lw(thin) lc(black)), xlabel(1.5 "Low SES" 4.5 "High SES" 7.5 "Low SES" 10.5 "High SES", notick labsize(small)) legend(label(1 "Same-sex") label(3 "Opposite-sex") order(1 3) rows(1) symx(*0.5) size(small) region(lc(none))) ylabel(-6(2)10) ytick(-6(1)10) text(-5 3 "Older-to-younger spillovers" -5 9 "Younger-to-older spillovers", size(small)) ytitle("Child born after school entry cutoff. Sibling" "spillovers in test scores (national percentiles)") xtitle("") graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A6.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A7. Heterogeneity analysis by gender of the focal child ***********************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen SS = ((female == 1 & female_sib == 1) | (female == 0 & female_sib == 0))
xtile mdiff = age_dif, n(2)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 0 & eFRL == 1, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 0 & eFRL == 0, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen SS = ((female == 1 & female_sib == 1) | (female == 0 & female_sib == 0))
xtile mdiff = age_dif, n(2)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a3 = _b[trt]
scalar a4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 0 & eFRL == 1, cluster(birth_dif_sib)
scalar b3 = _b[trt]
scalar b4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c3 = _b[trt]
scalar c4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female_sib == 0 & eFRL == 0, cluster(birth_dif_sib)
scalar d3 = _b[trt]
scalar d4 = _se[trt]

matrix X = (1\2\4\5\8\9\11\12)
matrix A = (a1\b1\c1\d1\a3\b3\c3\d3)
matrix B = (a2\b2\c2\d2\a4\b4\c4\d4)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3

keep in 1/8

rename Z1 X
rename Z2 E
rename Z3 SE

gen L = E-1.96*SE
gen U = E+1.96*SE

twoway (bar E X if X == 1 | X == 8, color(navy) fi(100)) (bar E X if X == 2 | X == 9, color(navy) fi(50)) (bar E X if X == 4 | X == 11, color(maroon) fi(100)) (bar E X if X == 5 | X == 12, color(maroon) fi(50)) (rspike L U X, lp(solid) lw(thin) lc(black)), xlabel(1 "Female" 2 "Male" 4 "Female" 5 "Male" 8 "Female" 9 "Male" 11 "Female" 12 "Male", notick labsize(small)) xtitle("Gender of focal child") ylabel(-8(2)8) ytick(-8(1)8) legend(label(1 "Low-SES") label(3 "High-SES") order(1 3) rows(1) symx(*0.5) region(lc(none))) text(-7.5 3 "Older-to-younger spillovers" -7.5 10 "Younger-to-older spillovers", size(small)) ytitle("Child born after school entry cutoff. Sibling" "spillovers in test scores (national percentiles)") graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A7.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A8. Heterogeneity analysis by gender of the sibling ***************************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen SS = ((female == 1 & female_sib == 1) | (female == 0 & female_sib == 0))
xtile mdiff = age_dif, n(2)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 0 & eFRL == 1, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 0 & eFRL == 0, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen SS = ((female == 1 & female_sib == 1) | (female == 0 & female_sib == 0))
xtile mdiff = age_dif, n(2)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a3 = _b[trt]
scalar a4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 0 & eFRL == 1, cluster(birth_dif_sib)
scalar b3 = _b[trt]
scalar b4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c3 = _b[trt]
scalar c4 = _se[trt]

reg scorep trt birth_dif_sib inter white i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & female == 0 & eFRL == 0, cluster(birth_dif_sib)
scalar d3 = _b[trt]
scalar d4 = _se[trt]

matrix X = (1\2\4\5\8\9\11\12)
matrix A = (a1\b1\c1\d1\a3\b3\c3\d3)
matrix B = (a2\b2\c2\d2\a4\b4\c4\d4)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3

keep in 1/8

rename Z1 X
rename Z2 E
rename Z3 SE

gen L = E-1.96*SE
gen U = E+1.96*SE

twoway (bar E X if X == 1 | X == 8, color(navy) fi(100)) (bar E X if X == 2 | X == 9, color(navy) fi(50)) (bar E X if X == 4 | X == 11, color(maroon) fi(100)) (bar E X if X == 5 | X == 12, color(maroon) fi(50)) (rspike L U X, lp(solid) lw(thin) lc(black)), xlabel(1 "Female" 2 "Male" 4 "Female" 5 "Male" 8 "Female" 9 "Male" 11 "Female" 12 "Male", notick labsize(small)) xtitle("") ylabel(-6(2)10) ytick(-7(1)10) legend(label(1 "Low-SES") label(3 "High-SES") order(1 3) rows(1) symx(*0.5) region(lc(none))) text(-6.5 3 "Older-to-younger spillovers" -6.5 10 "Younger-to-older spillovers", size(small)) ytitle("Child born after school entry cutoff. Sibling" "spillovers in test scores (national percentiles)") graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A8.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A9. Heterogeneity analysis by median spacing between siblings *****************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen SS = ((female == 1 & female_sib == 1) | (female == 0 & female_sib == 0))
xtile mdiff = age_dif, n(2)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a1 = _b[trt] 
scalar a2 = _se[trt]

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 2 & eFRL == 1, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 2 & eFRL == 0, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen SS = ((female == 1 & female_sib == 1) | (female == 0 & female_sib == 0))
xtile mdiff = age_dif, n(2)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 1 & eFRL == 1, cluster(birth_dif_sib)
scalar a3 = _b[trt]
scalar a4 = _se[trt]

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 2 & eFRL == 1, cluster(birth_dif_sib)
scalar b3 = _b[trt]
scalar b4 = _se[trt]

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 1 & eFRL == 0, cluster(birth_dif_sib)
scalar c3 = _b[trt]
scalar c4 = _se[trt]

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT female_sib if birth_dif_sib >= -59 & birth_dif_sib <= 60 & mdiff == 2 & eFRL == 0, cluster(birth_dif_sib)
scalar d3 = _b[trt]
scalar d4 = _se[trt]

matrix X = (1\2\4\5\8\9\11\12)
matrix A = (a1\b1\c1\d1\a3\b3\c3\d3)
matrix B = (a2\b2\c2\d2\a4\b4\c4\d4)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3

keep in 1/8

rename Z1 X
rename Z2 E
rename Z3 SE

gen L = E-1.96*SE
gen U = E+1.96*SE

twoway (bar E X if X == 1 | X == 8, color(navy) fi(100)) (bar E X if X == 2 | X == 9, color(navy) fi(50)) (bar E X if X == 4 | X == 11, color(maroon) fi(100)) (bar E X if X == 5 | X == 12, color(maroon) fi(50)) (rspike L U X, lp(solid) lw(thin) lc(black)), xlabel(1 "Below" 2 "Above" 4 "Below" 5 "Above" 8 "Below" 9 "Above" 11 "Below" 12 "Above", notick labsize(small)) xtitle("") ylabel(-6(2)10) ytick(-7(1)10) legend(label(1 "Low-SES") label(3 "High-SES") order(1 3) rows(1) symx(*0.5) region(lc(none))) text(-6.5 3 "Older-to-younger spillovers" -6.5 10 "Younger-to-older spillovers", size(small)) ytitle("Child born after school entry cutoff. Sibling" "spillovers in test scores (national percentiles)") graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A9.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A10. Unconditional quantile regression ****************************************************************************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

ta grade, gen(gr)
ta birthyear, gen(by)
ta birthmonth, gen(bm)
ta coh_sib, gen(cs)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in 25 50 75 {
rifreg scorep trt birth_dif_sib inter white female gr2-gr6 by2-by19 bm2-bm12 FCAT cs2-cs20 female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, q(`i') bootstrap reps(200)
scalar a`i' = _b[trt]
scalar b`i' = _se[trt]
*
rifreg scorep trt birth_dif_sib inter white female gr2-gr6 by2-by19 bm2-bm12 FCAT cs2-cs20 female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, q(`i') bootstrap reps(200)
scalar c`i' = _b[trt]
scalar d`i' = _se[trt]
}

matrix A = (a25\a50\a75)
matrix B = (b25\b50\b75)
matrix C = (c25\c50\c75)
matrix D = (d25\d50\d75)
matrix X = (1\2\3)

matrix E1 = (A\C)
matrix E2 = (B\D)
matrix X = (1\2\3\5\6\7)

matrix Z = (X,E1,E2)
svmat Z
keep Z1-Z3
keep in 1/6

rename Z1 X
rename Z2 E
rename Z3 SE

save  "Data\Temp\Jul21\OY-quantiles-oct18.dta", replace

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

ta grade, gen(gr)
ta birthyear, gen(by)
ta birthmonth, gen(bm)
ta coh_sib, gen(cs)

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

foreach i in 25 50 75 {
rifreg scorep trt birth_dif_sib inter white female gr2-gr6 by2-by18 bm2-bm12 FCAT cs2-cs19 female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, q(`i') bootstrap reps(200)
scalar a`i' = _b[trt]
scalar b`i' = _se[trt]
*
rifreg scorep trt birth_dif_sib inter white female gr2-gr6 by2-by18 bm2-bm12 FCAT cs2-cs19 female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, q(`i') bootstrap reps(200)
scalar c`i' = _b[trt]
scalar d`i' = _se[trt]
}

matrix A = (a25\a50\a75)
matrix B = (b25\b50\b75)
matrix C = (c25\c50\c75)
matrix D = (d25\d50\d75)
matrix X = (1\2\3)

matrix E1 = (A\C)
matrix E2 = (B\D)
matrix X = (9\10\11\13\14\15)

matrix Z = (X,E1,E2)
svmat Z
keep Z1-Z3
keep in 1/6

rename Z1 X
rename Z2 E
rename Z3 SE

save  "Data\Temp\Jul21\YO-quantiles-oct18.dta", replace

use "Data\Temp\Jul21\OY-quantiles-oct18.dta", clear
append using "Data\Temp\Jul21\YO-quantiles-oct18.dta"
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 5 | X == 9 | X == 13, color(navy)) (bar E X if X == 2 | X == 6 | X == 10 | X == 14, color(dkorange)) (bar E X if X == 3 | X == 7 | X == 11 | X == 15, color(maroon)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(2 "Lower-SES" 6 "Higher-SES" 10 "Lower-SES" 14 "Higher-SES", notick) xtitle("") ylabel(-6(2)8) ytick(-7(1)8) ytitle("Unconditional quantile estimates") legend(label(1 "25th") label(2 "Median") label(3 "75th") order(- "Percentiles:" 1 2 3) rows(1) symx(*0.5) region(lc(none))) text(-7 4 "Older-to-younger spillovers" -7 12 "Younger-to-older spillovers", size(small)) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A10.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A11. Robstness of the main results: Older-to-younger spillovers in test scores among all families *****************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

*** A - badwidth and functional form ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

forvalues k = 20(5)150 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k', cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib birth_dif_sib2 inter inter2 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k', cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
}


matrix X = (20\25\30\35\40\45\50\55\60\65\70\75\80\85\90\95\100\105\110\115\120\125\130\135\140\145\150)
matrix A = (a20\a25\a30\a35\a40\a45\a50\a55\a60\a65\a70\a75\a80\a85\a90\a95\a100\a105\a110\a115\a120\a125\a130\a135\a140\a145\a150)
matrix B = (b20\b25\b30\b35\b40\b45\b50\b55\b60\b65\b70\b75\b80\b85\b90\b95\b100\b105\b110\b115\b120\b125\b130\b135\b140\b145\b150)
matrix C = (c20\c25\c30\c35\c40\c45\c50\c55\c60\c65\c70\c75\c80\c85\c90\c95\c100\c105\c110\c115\c120\c125\c130\c135\c140\c145\c150)
matrix D = (d20\d25\d30\d35\d40\d45\d50\d55\d60\d65\d70\d75\d80\d85\d90\d95\d100\d105\d110\d115\d120\d125\d130\d135\d140\d145\d150)

matrix Z = (X,A,B,C,D)
svmat Z
keep Z1-Z5
keep in 1/27

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2

forvalues k = 1(1)2 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}


gen X1 = X-1
gen X2 = X+1

twoway (scatter E1 X1, msymbol(square) mcolor(navy) msize(small)) (scatter E2 X2, msymbol(circle) mcolor(dkorange) msize(small)) (rspike U1 L1 X1, lp(solid) lc(navy) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(dkorange) lw(thin)), ytitle("Older-to-younger spillovers in test scores" "for all families") xtitle("Bandwidth every 5 days (+/-)") xlabel(20(10)150) xtick(20(5)150) ylabel(-2(2)7) ytick(-3(1)7) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Local linear") label(2 "Quadratic") order(1 2) rows(1) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A11a.pdf", as(pdf) replace

*** B - donut regressions ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

keep if birth_dif_sib >= -59 & birth_dif_sib <= 60

forvalues k = 1(1)10 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)), cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (1\2\3\4\5\6\7\8\9\10)
matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/10

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E1 X, msymbol(circle) mcolor(black) msize(small)) (rspike U1 L1 X, lp(solid) lc(black) lw(thin)), ytitle("Older-to-younger spillovers in test scores" "for all families") xtitle("Dropping days around the threshold (+/-)") xlabel(1(1)10) ylabel(-1(1)4) ytick(-1(0.5)4) yline(0, lp(solid) lc(black) lw(thin)) legend(off) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A11b.pdf", as(pdf) replace

*** C - randomization test ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt0 = (birth_dif_sib > 0)
gen inter0 = trt0*birth_dif_sib

forvalues k = 1(1)100 {
gen birth_dif_sib_`k' = birth_dif_sib-`k'
gen birth_dif_sib`k' = birth_dif_sib+`k'

gen trt_`k'=(birth_dif_sib_`k'>0)
gen trt`k'=(birth_dif_sib`k'>0)

gen inter_`k'=trt_`k'*birth_dif_sib_`k'
gen inter`k'=trt`k'*birth_dif_sib`k'
}

reg scorep trt0 birth_dif_sib inter0 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar A0 = _b[trt0]
scalar B0 = _se[trt0]

forvalues k = 1(1)100 { 
reg scorep trt_`k' birth_dif_sib_`k' inter_`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib_`k' >= -59 & birth_dif_sib_`k' <= 60, cluster(birth_dif_sib)
scalar a`k' = _b[trt_`k']
scalar b`k' = _se[trt_`k']
reg scorep trt`k' birth_dif_sib`k' inter`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib`k' >= -59 & birth_dif_sib`k' <= 60, cluster(birth_dif_sib)
scalar c`k' = _b[trt`k']
scalar d`k' = _se[trt`k']
}


matrix X = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36\37\38\39\40\41\42\43\44\45\46\47\48\49\50\51\52\53\54\55\56\57\58\59\60\61\62\63\64\65\66\67\68\69\70\71\72\73\74\75\76\77\78\79\80\81\82\83\84\85\86\87\88\89\90\91\92\93\94\95\96\97\98\99\100)
matrix Y = X*(-1)

matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10\a11\a12\a13\a14\a15\a16\a17\a18\a19\a20\a21\a22\a23\a24\a25\a26\a27\a28\a29\a30\a31\a32\a33\a34\a35\a36\a37\a38\a39\a40\a41\a42\a43\a44\a45\a46\a47\a48\a49\a50\a51\a52\a53\a54\a55\a56\a57\a58\a59\a60\a61\a62\a63\a64\a65\a66\a67\a68\a69\a70\a71\a72\a73\a74\a75\a76\a77\a78\a79\a80\a81\a82\a83\a84\a85\a86\a87\a88\a89\a90\a91\a92\a93\a94\a95\a96\a97\a98\a99\a100)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10\b11\b12\b13\b14\b15\b16\b17\b18\b19\b20\b21\b22\b23\b24\b25\b26\b27\b28\b29\b30\b31\b32\b33\b34\b35\b36\b37\b38\b39\b40\b41\b42\b43\b44\b45\b46\b47\b48\b49\b50\b51\b52\b53\b54\b55\b56\b57\b58\b59\b60\b61\b62\b63\b64\b65\b66\b67\b68\b69\b70\b71\b72\b73\b74\b75\b76\b77\b78\b79\b80\b81\b82\b83\b84\b85\b86\b87\b88\b89\b90\b91\b92\b93\b94\b95\b96\b97\b98\b99\b100)

matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10\c11\c12\c13\c14\c15\c16\c17\c18\c19\c20\c21\c22\c23\c24\c25\c26\c27\c28\c29\c30\c31\c32\c33\c34\c35\c36\c37\c38\c39\c40\c41\c42\c43\c44\c45\c46\c47\c48\c49\c50\c51\c52\c53\c54\c55\c56\c57\c58\c59\c60\c61\c62\c63\c64\c65\c66\c67\c68\c69\c70\c71\c72\c73\c74\c75\c76\c77\c78\c79\c80\c81\c82\c83\c84\c85\c86\c87\c88\c89\c90\c91\c92\c93\c94\c95\c96\c97\c98\c99\c100)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10\d11\d12\d13\d14\d15\d16\d17\d18\d19\d20\d21\d22\d23\d24\d25\d26\d27\d28\d29\d30\d31\d32\d33\d34\d35\d36\d37\d38\d39\d40\d41\d42\d43\d44\d45\d46\d47\d48\d49\d50\d51\d52\d53\d54\d55\d56\d57\d58\d59\d60\d61\d62\d63\d64\d65\d66\d67\d68\d69\d70\d71\d72\d73\d74\d75\d76\d77\d78\d79\d80\d81\d82\d83\d84\d85\d86\d87\d88\d89\d90\d91\d92\d93\d94\d95\d96\d97\d98\d99\d100)

matrix Z1 = (Y\0\X)
matrix Z2 = (A\A0\C)

matrix V = (Z1,Z2)
svmat V
keep V1 V2
keep in 1/201

rename V1 X
rename V2 E1

twoway (kdensity E1, w(0.5) lp(solid) lc(black)), ylabel(0(0.1)0.5) xline(1.694, lp(dash) lc(black) lw(thick)) xlabel(-2.5(0.5)2) xtick(-2.5(0.25)2) xline(0, lp(solid) lc(black) lw(thin)) ytitle("Density") xtitle("Point estimates based on moving threshold by one day for +/- 100 days") legend(off) text(0.35 1.3 "RD estimate: 1.694", size(vsmall)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A11c.pdf", as(pdf) replace

*** D - sample restrictions ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

keep if coh_sib >= 1979
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idY id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idY

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

keep if BO == 2

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
drop if BO > 3
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar e1 = _b[trt]
scalar e2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idY)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idY)
egen temp3 = max(temp2), by(idY)
keep if temp3 >= 6
egen temp4 = seq(), by(idY)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar f1 = _b[trt]
scalar f2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idO id_sib
merge m:1 id_sib using "Data\Temp\Jul21\grade3score.dta"
keep if _merge == 3
drop _merge
rename id_sib idO

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar g1 = _b[trt]
scalar g2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idO id_sib
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs.dta"
keep if _merge == 3
drop _merge
rename id_sib idO

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar h1 = _b[trt]
scalar h2 = _se[trt]

matrix A = (a1\b1\c1\d1\e1\f1\g1\h1)
matrix B = (a2\b2\c2\d2\e2\f2\g2\h2)
matrix X = (1\3\5\7\9\11\13\15)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3
keep in 1/8
rename Z1 X
rename Z2 E
rename Z3 SE
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 3, color(navy)) (bar E X if X == 5 | X == 7 | X == 9, color(dkorange)) (bar E X if X == 11, color(maroon)) (bar E X if X == 13 | X == 15, color(khaki)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(1 "Baseline" 3 `" "September" "cutoff only" "' 5 `" "Fully" "observed" "' 7 `" "First two" "births" "' 9 `" "Parity one" "and two" "' 11 `" "Grades" "3 to 8" "' 13 `" "3rd grade" "scores" "' 15 `" "KG" "attendance" "', labsize(small)) xtitle("Sample restrictions") ytitle("Older-to-younger spillovers in test scores" "for all families") legend(label(1 "General") label(2 "Birth order related") label(3 "Panel analysis") label(4 "Focal child information related") order(1 2 3 4) rows(2)symx(*0.5) region(lc(none))) ylabel(-2(2)6) ytick(-3(1)6) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A11d.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A12. Robustness of the main results: Older-to-younger spillovers in test scores among high SES families ***********************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

*** A - badwidth and functional form ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

forvalues k = 20(5)150 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 0, cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib birth_dif_sib2 inter inter2 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 0, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
}


matrix X = (20\25\30\35\40\45\50\55\60\65\70\75\80\85\90\95\100\105\110\115\120\125\130\135\140\145\150)
matrix A = (a20\a25\a30\a35\a40\a45\a50\a55\a60\a65\a70\a75\a80\a85\a90\a95\a100\a105\a110\a115\a120\a125\a130\a135\a140\a145\a150)
matrix B = (b20\b25\b30\b35\b40\b45\b50\b55\b60\b65\b70\b75\b80\b85\b90\b95\b100\b105\b110\b115\b120\b125\b130\b135\b140\b145\b150)
matrix C = (c20\c25\c30\c35\c40\c45\c50\c55\c60\c65\c70\c75\c80\c85\c90\c95\c100\c105\c110\c115\c120\c125\c130\c135\c140\c145\c150)
matrix D = (d20\d25\d30\d35\d40\d45\d50\d55\d60\d65\d70\d75\d80\d85\d90\d95\d100\d105\d110\d115\d120\d125\d130\d135\d140\d145\d150)

matrix Z = (X,A,B,C,D)
svmat Z
keep Z1-Z5
keep in 1/27

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2

forvalues k = 1(1)2 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}


gen X1 = X-1
gen X2 = X+1

twoway (scatter E1 X1, msymbol(square) mcolor(navy) msize(small)) (scatter E2 X2, msymbol(circle) mcolor(dkorange) msize(small)) (rspike U1 L1 X1, lp(solid) lc(navy) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(dkorange) lw(thin)), ytitle("Older-to-younger spillovers in test scores" "for families never on free or reduced price lunch") xtitle("Bandwidth every 5 days (+/-)") xlabel(20(10)150) xtick(20(5)150) ylabel(-4(2)10) ytick(-4(1)10) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Local linear") label(2 "Quadratic") order(1 2) rows(1) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A12a.pdf", as(pdf) replace

*** B - donut regressions ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

keep if birth_dif_sib >= -59 & birth_dif_sib <= 60

forvalues k = 1(1)10 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)), cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (1\2\3\4\5\6\7\8\9\10)
matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/10

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E3 X, msymbol(circle) mcolor(black) msize(small)) (rspike U3 L3 X, lp(solid) lc(black) lw(thin)), ytitle("Older-to-younger spillovers in test scores" "for families never on free or reduced price lunch") xtitle("Dropping days around the threshold (+/-)") xlabel(1(1)10) ylabel(-6(1)3) ytick(-6(0.5)3) yline(0, lp(solid) lc(black) lw(thin)) legend(off) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A12b.pdf", as(pdf) replace

*** C - randomization test ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt0 = (birth_dif_sib > 0)
gen inter0 = trt0*birth_dif_sib

forvalues k = 1(1)100 {
gen birth_dif_sib_`k' = birth_dif_sib-`k'
gen birth_dif_sib`k' = birth_dif_sib+`k'

gen trt_`k'=(birth_dif_sib_`k'>0)
gen trt`k'=(birth_dif_sib`k'>0)

gen inter_`k'=trt_`k'*birth_dif_sib_`k'
gen inter`k'=trt`k'*birth_dif_sib`k'
}

reg scorep trt0 birth_dif_sib inter0 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar I0 = _b[trt0]
scalar J0 = _se[trt0]

forvalues k = 1(1)100 { 
reg scorep trt_`k' birth_dif_sib_`k' inter_`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib_`k' >= -59 & birth_dif_sib_`k' <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar i`k' = _b[trt_`k']
scalar j`k' = _se[trt_`k']
reg scorep trt`k' birth_dif_sib`k' inter`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib`k' >= -59 & birth_dif_sib`k' <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar k`k' = _b[trt`k']
scalar l`k' = _se[trt`k']
}


matrix X = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36\37\38\39\40\41\42\43\44\45\46\47\48\49\50\51\52\53\54\55\56\57\58\59\60\61\62\63\64\65\66\67\68\69\70\71\72\73\74\75\76\77\78\79\80\81\82\83\84\85\86\87\88\89\90\91\92\93\94\95\96\97\98\99\100)
matrix Y = X*(-1)

matrix I = (i1\i2\i3\i4\i5\i6\i7\i8\i9\i10\i11\i12\i13\i14\i15\i16\i17\i18\i19\i20\i21\i22\i23\i24\i25\i26\i27\i28\i29\i30\i31\i32\i33\i34\i35\i36\i37\i38\i39\i40\i41\i42\i43\i44\i45\i46\i47\i48\i49\i50\i51\i52\i53\i54\i55\i56\i57\i58\i59\i60\i61\i62\i63\i64\i65\i66\i67\i68\i69\i70\i71\i72\i73\i74\i75\i76\i77\i78\i79\i80\i81\i82\i83\i84\i85\i86\i87\i88\i89\i90\i91\i92\i93\i94\i95\i96\i97\i98\i99\i100)
matrix J = (j1\j2\j3\j4\j5\j6\j7\j8\j9\j10\j11\j12\j13\j14\j15\j16\j17\j18\j19\j20\j21\j22\j23\j24\j25\j26\j27\j28\j29\j30\j31\j32\j33\j34\j35\j36\j37\j38\j39\j40\j41\j42\j43\j44\j45\j46\j47\j48\j49\j50\j51\j52\j53\j54\j55\j56\j57\j58\j59\j60\j61\j62\j63\j64\j65\j66\j67\j68\j69\j70\j71\j72\j73\j74\j75\j76\j77\j78\j79\j80\j81\j82\j83\j84\j85\j86\j87\j88\j89\j90\j91\j92\j93\j94\j95\j96\j97\j98\j99\j100)

matrix K = (k1\k2\k3\k4\k5\k6\k7\k8\k9\k10\k11\k12\k13\k14\k15\k16\k17\k18\k19\k20\k21\k22\k23\k24\k25\k26\k27\k28\k29\k30\k31\k32\k33\k34\k35\k36\k37\k38\k39\k40\k41\k42\k43\k44\k45\k46\k47\k48\k49\k50\k51\k52\k53\k54\k55\k56\k57\k58\k59\k60\k61\k62\k63\k64\k65\k66\k67\k68\k69\k70\k71\k72\k73\k74\k75\k76\k77\k78\k79\k80\k81\k82\k83\k84\k85\k86\k87\k88\k89\k90\k91\k92\k93\k94\k95\k96\k97\k98\k99\k100)
matrix L = (l1\l2\l3\l4\l5\l6\l7\l8\l9\l10\l11\l12\l13\l14\l15\l16\l17\l18\l19\l20\l21\l22\l23\l24\l25\l26\l27\l28\l29\l30\l31\l32\l33\l34\l35\l36\l37\l38\l39\l40\l41\l42\l43\l44\l45\l46\l47\l48\l49\l50\l51\l52\l53\l54\l55\l56\l57\l58\l59\l60\l61\l62\l63\l64\l65\l66\l67\l68\l69\l70\l71\l72\l73\l74\l75\l76\l77\l78\l79\l80\l81\l82\l83\l84\l85\l86\l87\l88\l89\l90\l91\l92\l93\l94\l95\l96\l97\l98\l99\l100)

matrix Z1 = (Y\0\X)
matrix Z2 = (I\I0\K)

matrix V = (Z1,Z2)
svmat V
keep V1 V2
keep in 1/201

rename V1 X
rename V2 E1

twoway (kdensity E1, w(0.5) lp(solid) lc(black)), ylabel(0(0.1)0.4) xline(-0.076, lp(dash) lc(black) lw(thick)) xlabel(-3(0.5)2.0) xtick(-3(0.25)2.25) xline(0, lp(solid) lc(black) lw(thin)) ytitle("Density") xtitle("Point estimates based on moving threshold by one day for +/- 100 days") legend(off) text(0.39 -0.52 "RD estimate: -0.076", size(vsmall)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A12c.pdf", as(pdf) replace

*** D - sample restrictions ***

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996

keep if coh_sib >= 1979
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idY id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idY

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

keep if BO == 2

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
drop if BO > 3
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar e1 = _b[trt]
scalar e2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idY)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idY)
egen temp3 = max(temp2), by(idY)
keep if temp3 >= 6
egen temp4 = seq(), by(idY)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar f1 = _b[trt]
scalar f2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idO id_sib
merge m:1 id_sib using "Data\Temp\Jul21\grade3score.dta"
keep if _merge == 3
drop _merge
rename id_sib idO

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar g1 = _b[trt]
scalar g2 = _se[trt]

use "Data\Temp\Jul21\main_older-to-younger-with-scores.dta", clear
keep if birthyear >= 1978 & birthyear <= 1996
drop if coh_sib <= 1975 | coh_sib == 1996
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idO id_sib
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs.dta"
keep if _merge == 3
drop _merge
rename id_sib idO

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar h1 = _b[trt]
scalar h2 = _se[trt]

matrix A = (a1\b1\c1\d1\e1\f1\g1\h1)
matrix B = (a2\b2\c2\d2\e2\f2\g2\h2)
matrix X = (1\3\5\7\9\11\13\15)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3
keep in 1/8
rename Z1 X
rename Z2 E
rename Z3 SE
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 3, color(navy)) (bar E X if X == 5 | X == 7 | X == 9, color(dkorange)) (bar E X if X == 11, color(maroon)) (bar E X if X == 13 | X == 15, color(khaki)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(1 "Baseline" 3 `" "September" "cutoff only" "' 5 `" "Fully" "observed" "' 7 `" "First two" "births" "' 9 `" "Parity one" "and two" "' 11 `" "Grades" "3 to 8" "' 13 `" "3rd grade" "scores" "' 15 `" "KG" "attendance" "', labsize(small)) xtitle("Sample restrictions") ytitle("Older-to-younger spillovers in test scores for" "families never on free or reduced price lunch") legend(label(1 "General") label(2 "Birth order related") label(3 "Panel analysis") label(4 "Focal child information related") order(1 2 3 4) rows(2)symx(*0.5) region(lc(none))) ylabel(-6(2)8) ytick(-6(1)8) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A12d.pdf", as(pdf) replace


**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A13. Robustness of the main results: Younger-to-older spillovers in test scores among all families ****************************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

*** A - badwidth and functional form ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

forvalues k = 20(5)150 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k', cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib birth_dif_sib2 inter inter2 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k', cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
}


matrix X = (20\25\30\35\40\45\50\55\60\65\70\75\80\85\90\95\100\105\110\115\120\125\130\135\140\145\150)
matrix A = (a20\a25\a30\a35\a40\a45\a50\a55\a60\a65\a70\a75\a80\a85\a90\a95\a100\a105\a110\a115\a120\a125\a130\a135\a140\a145\a150)
matrix B = (b20\b25\b30\b35\b40\b45\b50\b55\b60\b65\b70\b75\b80\b85\b90\b95\b100\b105\b110\b115\b120\b125\b130\b135\b140\b145\b150)
matrix C = (c20\c25\c30\c35\c40\c45\c50\c55\c60\c65\c70\c75\c80\c85\c90\c95\c100\c105\c110\c115\c120\c125\c130\c135\c140\c145\c150)
matrix D = (d20\d25\d30\d35\d40\d45\d50\d55\d60\d65\d70\d75\d80\d85\d90\d95\d100\d105\d110\d115\d120\d125\d130\d135\d140\d145\d150)

matrix Z = (X,A,B,C,D)
svmat Z
keep Z1-Z5
keep in 1/27

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2

forvalues k = 1(1)2 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}


gen X1 = X-1
gen X2 = X+1

twoway (scatter E1 X1, msymbol(square) mcolor(navy) msize(small)) (scatter E2 X2, msymbol(circle) mcolor(dkorange) msize(small)) (rspike U1 L1 X1, lp(solid) lc(navy) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(dkorange) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for all families") xtitle("Bandwidth every 5 days (+/-)") xlabel(20(10)150) xtick(20(5)150) ylabel(-4(2)6) ytick(-4(1)6) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Local linear") label(2 "Quadratic") order(1 2) rows(1) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A13a.pdf", as(pdf) replace

*** B - donut regressions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

keep if birth_dif_sib >= -59 & birth_dif_sib <= 60

forvalues k = 1(1)10 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)), cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (1\2\3\4\5\6\7\8\9\10)
matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/10

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E1 X, msymbol(circle) mcolor(black) msize(small)) (rspike U1 L1 X, lp(solid) lc(black) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for all families") xtitle("Dropping days around the threshold (+/-)") xlabel(1(1)10) ylabel(-4(1)2) ytick(-4(0.5)2) yline(0, lp(solid) lc(black) lw(thin)) legend(off) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A13b.pdf", as(pdf) replace

*** C - randomization test ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt0 = (birth_dif_sib > 0)
gen inter0 = trt0*birth_dif_sib

forvalues k = 1(1)100 {
gen birth_dif_sib_`k' = birth_dif_sib-`k'
gen birth_dif_sib`k' = birth_dif_sib+`k'

gen trt_`k'=(birth_dif_sib_`k'>0)
gen trt`k'=(birth_dif_sib`k'>0)

gen inter_`k'=trt_`k'*birth_dif_sib_`k'
gen inter`k'=trt`k'*birth_dif_sib`k'
}

reg scorep trt0 birth_dif_sib inter0 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar A0 = _b[trt0]
scalar B0 = _se[trt0]

forvalues k = 1(1)100 { 
reg scorep trt_`k' birth_dif_sib_`k' inter_`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib_`k' >= -59 & birth_dif_sib_`k' <= 60, cluster(birth_dif_sib)
scalar a`k' = _b[trt_`k']
scalar b`k' = _se[trt_`k']
reg scorep trt`k' birth_dif_sib`k' inter`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib`k' >= -59 & birth_dif_sib`k' <= 60, cluster(birth_dif_sib)
scalar c`k' = _b[trt`k']
scalar d`k' = _se[trt`k']
}


matrix X = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36\37\38\39\40\41\42\43\44\45\46\47\48\49\50\51\52\53\54\55\56\57\58\59\60\61\62\63\64\65\66\67\68\69\70\71\72\73\74\75\76\77\78\79\80\81\82\83\84\85\86\87\88\89\90\91\92\93\94\95\96\97\98\99\100)
matrix Y = X*(-1)

matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10\a11\a12\a13\a14\a15\a16\a17\a18\a19\a20\a21\a22\a23\a24\a25\a26\a27\a28\a29\a30\a31\a32\a33\a34\a35\a36\a37\a38\a39\a40\a41\a42\a43\a44\a45\a46\a47\a48\a49\a50\a51\a52\a53\a54\a55\a56\a57\a58\a59\a60\a61\a62\a63\a64\a65\a66\a67\a68\a69\a70\a71\a72\a73\a74\a75\a76\a77\a78\a79\a80\a81\a82\a83\a84\a85\a86\a87\a88\a89\a90\a91\a92\a93\a94\a95\a96\a97\a98\a99\a100)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10\b11\b12\b13\b14\b15\b16\b17\b18\b19\b20\b21\b22\b23\b24\b25\b26\b27\b28\b29\b30\b31\b32\b33\b34\b35\b36\b37\b38\b39\b40\b41\b42\b43\b44\b45\b46\b47\b48\b49\b50\b51\b52\b53\b54\b55\b56\b57\b58\b59\b60\b61\b62\b63\b64\b65\b66\b67\b68\b69\b70\b71\b72\b73\b74\b75\b76\b77\b78\b79\b80\b81\b82\b83\b84\b85\b86\b87\b88\b89\b90\b91\b92\b93\b94\b95\b96\b97\b98\b99\b100)

matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10\c11\c12\c13\c14\c15\c16\c17\c18\c19\c20\c21\c22\c23\c24\c25\c26\c27\c28\c29\c30\c31\c32\c33\c34\c35\c36\c37\c38\c39\c40\c41\c42\c43\c44\c45\c46\c47\c48\c49\c50\c51\c52\c53\c54\c55\c56\c57\c58\c59\c60\c61\c62\c63\c64\c65\c66\c67\c68\c69\c70\c71\c72\c73\c74\c75\c76\c77\c78\c79\c80\c81\c82\c83\c84\c85\c86\c87\c88\c89\c90\c91\c92\c93\c94\c95\c96\c97\c98\c99\c100)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10\d11\d12\d13\d14\d15\d16\d17\d18\d19\d20\d21\d22\d23\d24\d25\d26\d27\d28\d29\d30\d31\d32\d33\d34\d35\d36\d37\d38\d39\d40\d41\d42\d43\d44\d45\d46\d47\d48\d49\d50\d51\d52\d53\d54\d55\d56\d57\d58\d59\d60\d61\d62\d63\d64\d65\d66\d67\d68\d69\d70\d71\d72\d73\d74\d75\d76\d77\d78\d79\d80\d81\d82\d83\d84\d85\d86\d87\d88\d89\d90\d91\d92\d93\d94\d95\d96\d97\d98\d99\d100)

matrix Z1 = (Y\0\X)
matrix Z2 = (A\A0\C)

matrix V = (Z1,Z2)
svmat V
keep V1 V2
keep in 1/201

rename V1 X
rename V2 E1

twoway (kdensity E1, w(0.5) lp(solid) lc(black)), ylabel(0(0.1)0.5) xline(-0.588, lp(dash) lc(black) lw(thick)) xlabel(-2(0.5)2) xtick(-2(0.25)2.25) xline(0, lp(solid) lc(black) lw(thin)) ytitle("Density") xtitle("Point estimates based on moving threshold by one day for +/- 100 days") legend(off) text(0.48 -0.95 "RD estimate: -0.588", size(vsmall)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A13c.pdf", as(pdf) replace

*** D - sample restrictions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

keep if coh_sib >= 1979
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

keep if BO == 1

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
drop BO
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO
drop if BO > 2

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar e1 = _b[trt]
scalar e2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idO)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idO)
egen temp3 = max(temp2), by(idO)
keep if temp3 >= 6
egen temp4 = seq(), by(idO)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar f1 = _b[trt]
scalar f2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\grade3score.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar g1 = _b[trt]
scalar g2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60, cluster(birth_dif_sib)
scalar h1 = _b[trt]
scalar h2 = _se[trt]

matrix A = (a1\b1\c1\d1\e1\f1\g1\h1)
matrix B = (a2\b2\c2\d2\e2\f2\g2\h2)
matrix X = (1\3\5\7\9\11\13\15)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3
keep in 1/8
rename Z1 X
rename Z2 E
rename Z3 SE
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 3, color(navy)) (bar E X if X == 5 | X == 7 | X == 9, color(dkorange)) (bar E X if X == 11, color(maroon)) (bar E X if X == 13 | X == 15, color(khaki)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(1 "Baseline" 3 `" "September" "cutoff only" "' 5 `" "Fully" "observed" "' 7 `" "First two" "births" "' 9 `" "Parity one" "and two" "' 11 `" "Grades" "3 to 8" "' 13 `" "3rd grade" "scores" "' 15 `" "KG" "attendance" "', labsize(small)) xtitle("Sample restrictions") ytitle("Younger-to-older spillovers in test scores" "for all families") legend(label(1 "General") label(2 "Birth order related") label(3 "Panel analysis") label(4 "Focal child information related") order(1 2 3 4) rows(2)symx(*0.5) region(lc(none))) ylabel(-4(2)4) ytick(-4(1)4) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A13d.pdf", as(pdf) replace

**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
******* Figure A14. Robustness of the main results: Younger-to-older spillovers in test scores among lower SES families **********************************
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

*** A - badwidth and functional form ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

forvalues k = 20(5)150 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 1, cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib birth_dif_sib2 inter inter2 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
}


matrix X = (20\25\30\35\40\45\50\55\60\65\70\75\80\85\90\95\100\105\110\115\120\125\130\135\140\145\150)
matrix A = (a20\a25\a30\a35\a40\a45\a50\a55\a60\a65\a70\a75\a80\a85\a90\a95\a100\a105\a110\a115\a120\a125\a130\a135\a140\a145\a150)
matrix B = (b20\b25\b30\b35\b40\b45\b50\b55\b60\b65\b70\b75\b80\b85\b90\b95\b100\b105\b110\b115\b120\b125\b130\b135\b140\b145\b150)
matrix C = (c20\c25\c30\c35\c40\c45\c50\c55\c60\c65\c70\c75\c80\c85\c90\c95\c100\c105\c110\c115\c120\c125\c130\c135\c140\c145\c150)
matrix D = (d20\d25\d30\d35\d40\d45\d50\d55\d60\d65\d70\d75\d80\d85\d90\d95\d100\d105\d110\d115\d120\d125\d130\d135\d140\d145\d150)

matrix Z = (X,A,B,C,D)
svmat Z
keep Z1-Z5
keep in 1/27

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2

forvalues k = 1(1)2 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}


gen X1 = X-1
gen X2 = X+1

twoway (scatter E1 X1, msymbol(square) mcolor(navy) msize(small)) (scatter E2 X2, msymbol(circle) mcolor(dkorange) msize(small)) (rspike U1 L1 X1, lp(solid) lc(navy) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(dkorange) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for families ever on free or reduced price lunch") xtitle("Bandwidth every 5 days (+/-)") xlabel(20(10)150) xtick(20(5)150) ylabel(-6(2)6) ytick(-7(1)6) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Local linear") label(2 "Quadratic") order(1 2) rows(1) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A14a.pdf", as(pdf) replace

*** B - donut regressions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

keep if birth_dif_sib >= -59 & birth_dif_sib <= 60

forvalues k = 1(1)10 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)), cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (1\2\3\4\5\6\7\8\9\10)
matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/10

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E2 X, msymbol(circle) mcolor(black) msize(small)) (rspike U2 L2 X, lp(solid) lc(black) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for families ever on free or reduced price lunch") xtitle("Dropping days around the threshold (+/-)") xlabel(1(1)10) ylabel(-3(1)6) ytick(-3(0.5)6) yline(0, lp(solid) lc(black) lw(thin)) legend(off) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A14b.pdf", as(pdf) replace

*** C - randomization test ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt0 = (birth_dif_sib > 0)
gen inter0 = trt0*birth_dif_sib

forvalues k = 1(1)100 {
gen birth_dif_sib_`k' = birth_dif_sib-`k'
gen birth_dif_sib`k' = birth_dif_sib+`k'

gen trt_`k'=(birth_dif_sib_`k'>0)
gen trt`k'=(birth_dif_sib`k'>0)

gen inter_`k'=trt_`k'*birth_dif_sib_`k'
gen inter`k'=trt`k'*birth_dif_sib`k'
}

reg scorep trt0 birth_dif_sib inter0 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar E0 = _b[trt0]
scalar F0 = _se[trt0]

forvalues k = 1(1)100 { 
reg scorep trt_`k' birth_dif_sib_`k' inter_`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib_`k' >= -59 & birth_dif_sib_`k' <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar e`k' = _b[trt_`k']
scalar f`k' = _se[trt_`k']
reg scorep trt`k' birth_dif_sib`k' inter`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib`k' >= -59 & birth_dif_sib`k' <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar g`k' = _b[trt`k']
scalar h`k' = _se[trt`k']
}


matrix X = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36\37\38\39\40\41\42\43\44\45\46\47\48\49\50\51\52\53\54\55\56\57\58\59\60\61\62\63\64\65\66\67\68\69\70\71\72\73\74\75\76\77\78\79\80\81\82\83\84\85\86\87\88\89\90\91\92\93\94\95\96\97\98\99\100)
matrix Y = X*(-1)

matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10\e11\e12\e13\e14\e15\e16\e17\e18\e19\e20\e21\e22\e23\e24\e25\e26\e27\e28\e29\e30\e31\e32\e33\e34\e35\e36\e37\e38\e39\e40\e41\e42\e43\e44\e45\e46\e47\e48\e49\e50\e51\e52\e53\e54\e55\e56\e57\e58\e59\e60\e61\e62\e63\e64\e65\e66\e67\e68\e69\e70\e71\e72\e73\e74\e75\e76\e77\e78\e79\e80\e81\e82\e83\e84\e85\e86\e87\e88\e89\e90\e91\e92\e93\e94\e95\e96\e97\e98\e99\e100)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10\f11\f12\f13\f14\f15\f16\f17\f18\f19\f20\f21\f22\f23\f24\f25\f26\f27\f28\f29\f30\f31\f32\f33\f34\f35\f36\f37\f38\f39\f40\f41\f42\f43\f44\f45\f46\f47\f48\f49\f50\f51\f52\f53\f54\f55\f56\f57\f58\f59\f60\f61\f62\f63\f64\f65\f66\f67\f68\f69\f70\f71\f72\f73\f74\f75\f76\f77\f78\f79\f80\f81\f82\f83\f84\f85\f86\f87\f88\f89\f90\f91\f92\f93\f94\f95\f96\f97\f98\f99\f100)

matrix G = (g1\g2\g3\g4\g5\g6\g7\g8\g9\g10\g11\g12\g13\g14\g15\g16\g17\g18\g19\g20\g21\g22\g23\g24\g25\g26\g27\g28\g29\g30\g31\g32\g33\g34\g35\g36\g37\g38\g39\g40\g41\g42\g43\g44\g45\g46\g47\g48\g49\g50\g51\g52\g53\g54\g55\g56\g57\g58\g59\g60\g61\g62\g63\g64\g65\g66\g67\g68\g69\g70\g71\g72\g73\g74\g75\g76\g77\g78\g79\g80\g81\g82\g83\g84\g85\g86\g87\g88\g89\g90\g91\g92\g93\g94\g95\g96\g97\g98\g99\g100)
matrix H = (h1\h2\h3\h4\h5\h6\h7\h8\h9\h10\h11\h12\h13\h14\h15\h16\h17\h18\h19\h20\h21\h22\h23\h24\h25\h26\h27\h28\h29\h30\h31\h32\h33\h34\h35\h36\h37\h38\h39\h40\h41\h42\h43\h44\h45\h46\h47\h48\h49\h50\h51\h52\h53\h54\h55\h56\h57\h58\h59\h60\h61\h62\h63\h64\h65\h66\h67\h68\h69\h70\h71\h72\h73\h74\h75\h76\h77\h78\h79\h80\h81\h82\h83\h84\h85\h86\h87\h88\h89\h90\h91\h92\h93\h94\h95\h96\h97\h98\h99\h100)

matrix Z1 = (Y\0\X)
matrix Z2 = (E\E0\G)

matrix V = (Z1,Z2)
svmat V
keep V1 V2
keep in 1/201

rename V1 X
rename V2 E1

twoway (kdensity E1, w(0.5) lp(solid) lc(black)), ylabel(0(0.1)0.4) xline(0.809, lp(dash) lc(black) lw(thick)) xlabel(-3(0.5)2.5) xtick(-3(0.25)2.5) xline(0, lp(solid) lc(black) lw(thin)) ytitle("Density") xtitle("Point estimates based on moving threshold by one day for +/- 100 days") legend(off) text(0.35 1.3 "RD estimate: 0.809", size(vsmall)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A14c.pdf", as(pdf) replace

*** D - sample restrictions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

keep if coh_sib >= 1979
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

keep if BO == 1

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
drop BO
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO
drop if BO > 2

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar e1 = _b[trt]
scalar e2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idO)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idO)
egen temp3 = max(temp2), by(idO)
keep if temp3 >= 6
egen temp4 = seq(), by(idO)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar f1 = _b[trt]
scalar f2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\grade3score.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar g1 = _b[trt]
scalar g2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 1, cluster(birth_dif_sib)
scalar h1 = _b[trt]
scalar h2 = _se[trt]

matrix A = (a1\b1\c1\d1\e1\f1\g1\h1)
matrix B = (a2\b2\c2\d2\e2\f2\g2\h2)
matrix X = (1\3\5\7\9\11\13\15)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3
keep in 1/8
rename Z1 X
rename Z2 E
rename Z3 SE
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 3, color(navy)) (bar E X if X == 5 | X == 7 | X == 9, color(dkorange)) (bar E X if X == 11, color(maroon)) (bar E X if X == 13 | X == 15, color(khaki)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(1 "Baseline" 3 `" "September" "cutoff only" "' 5 `" "Fully" "observed" "' 7 `" "First two" "births" "' 9 `" "Parity one" "and two" "' 11 `" "Grades" "3 to 8" "' 13 `" "3rd grade" "scores" "' 15 `" "KG" "attendance" "', labsize(small)) xtitle("Sample restrictions") ytitle("Younger-to-older spillovers in test scores for" "families ever on free or reduced price lunch") legend(label(1 "General") label(2 "Birth order related") label(3 "Panel analysis") label(4 "Focal child information related") order(1 2 3 4) rows(2)symx(*0.5) region(lc(none))) ylabel(-4(2)6) ytick(-4(1)6) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A14d.pdf", as(pdf) replace

*****************************************************************************************************************************************************************************
*****************************************************************************************************************************************************************************
** Figure A15. Younger-to-older spillovers in test scores among higher SES families: Sample of older children after the commencement of testing of the younger focal child **
*****************************************************************************************************************************************************************************
*****************************************************************************************************************************************************************************

*** A - badwidth and functional form ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

forvalues k = 20(5)150 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 0, cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib birth_dif_sib2 inter inter2 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -`k'+1 & birth_dif_sib <= `k' & eFRL == 0, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
}


matrix X = (20\25\30\35\40\45\50\55\60\65\70\75\80\85\90\95\100\105\110\115\120\125\130\135\140\145\150)
matrix A = (a20\a25\a30\a35\a40\a45\a50\a55\a60\a65\a70\a75\a80\a85\a90\a95\a100\a105\a110\a115\a120\a125\a130\a135\a140\a145\a150)
matrix B = (b20\b25\b30\b35\b40\b45\b50\b55\b60\b65\b70\b75\b80\b85\b90\b95\b100\b105\b110\b115\b120\b125\b130\b135\b140\b145\b150)
matrix C = (c20\c25\c30\c35\c40\c45\c50\c55\c60\c65\c70\c75\c80\c85\c90\c95\c100\c105\c110\c115\c120\c125\c130\c135\c140\c145\c150)
matrix D = (d20\d25\d30\d35\d40\d45\d50\d55\d60\d65\d70\d75\d80\d85\d90\d95\d100\d105\d110\d115\d120\d125\d130\d135\d140\d145\d150)

matrix Z = (X,A,B,C,D)
svmat Z
keep Z1-Z5
keep in 1/27

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2

forvalues k = 1(1)2 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}


gen X1 = X-1
gen X2 = X+1

twoway (scatter E1 X1, msymbol(square) mcolor(navy) msize(small)) (scatter E2 X2, msymbol(circle) mcolor(dkorange) msize(small)) (rspike U1 L1 X1, lp(solid) lc(navy) lw(thin)) (rspike U2 L2 X2, lp(solid) lc(dkorange) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for families never on free or reduced price lunch") xtitle("Bandwidth every 5 days (+/-)") xlabel(20(10)150) xtick(20(5)150) ylabel(-8(2)6) ytick(-9(1)7) yline(0, lp(solid) lc(black) lw(thin)) legend(label(1 "Local linear") label(2 "Quadratic") order(1 2) rows(1) region(lc(none))) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A15a.pdf", as(pdf) replace

*** B - donut regressions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 


gen FCAT = (test == "FCAT")

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen birth_dif_sib2 = birth_dif_sib*birth_dif_sib
gen inter2 = trt*birth_dif_sib2

keep if birth_dif_sib >= -59 & birth_dif_sib <= 60

forvalues k = 1(1)10 { 
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)), cluster(birth_dif_sib)
scalar a`k' = _b[trt]
scalar b`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 1, cluster(birth_dif_sib)
scalar c`k' = _b[trt]
scalar d`k' = _se[trt]
reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if ((birth_dif_sib >= -59 & birth_dif_sib <= -`k') | (birth_dif_sib > `k' & birth_dif_sib <= 60)) & eFRL == 0, cluster(birth_dif_sib)
scalar e`k' = _b[trt]
scalar f`k' = _se[trt]
}


matrix X = (1\2\3\4\5\6\7\8\9\10)
matrix A = (a1\a2\a3\a4\a5\a6\a7\a8\a9\a10)
matrix B = (b1\b2\b3\b4\b5\b6\b7\b8\b9\b10)
matrix C = (c1\c2\c3\c4\c5\c6\c7\c8\c9\c10)
matrix D = (d1\d2\d3\d4\d5\d6\d7\d8\d9\d10)
matrix E = (e1\e2\e3\e4\e5\e6\e7\e8\e9\e10)
matrix F = (f1\f2\f3\f4\f5\f6\f7\f8\f9\f10)

matrix Z = (X,A,B,C,D,E,F)
svmat Z
keep Z1-Z7
keep in 1/10

rename Z1 X
rename Z2 E1
rename Z3 SE1
rename Z4 E2
rename Z5 SE2
rename Z6 E3
rename Z7 SE3

forvalues k = 1(1)3 {
gen U`k' = E`k' + 1.96*SE`k'
gen L`k' = E`k' - 1.96*SE`k'
}

gen X1 = X-0.25
gen X2 = X
gen X3 = X+0.25

twoway (scatter E3 X, msymbol(circle) mcolor(black) msize(small)) (rspike U3 L3 X, lp(solid) lc(black) lw(thin)), ytitle("Younger-to-older spillovers in test scores" "for families never on free or reduced price lunch") xtitle("Dropping days around the threshold (+/-)") xlabel(1(1)10) ylabel(-8(2)0) ytick(-8(1)1) yline(0, lp(solid) lc(black) lw(thin)) legend(off) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A15b.pdf", as(pdf) replace

*** C - randomization test ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen trt0 = (birth_dif_sib > 0)
gen inter0 = trt0*birth_dif_sib

forvalues k = 1(1)100 {
gen birth_dif_sib_`k' = birth_dif_sib-`k'
gen birth_dif_sib`k' = birth_dif_sib+`k'

gen trt_`k'=(birth_dif_sib_`k'>0)
gen trt`k'=(birth_dif_sib`k'>0)

gen inter_`k'=trt_`k'*birth_dif_sib_`k'
gen inter`k'=trt`k'*birth_dif_sib`k'
}

reg scorep trt0 birth_dif_sib inter0 white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar I0 = _b[trt0]
scalar J0 = _se[trt0]

forvalues k = 1(1)100 { 
reg scorep trt_`k' birth_dif_sib_`k' inter_`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib_`k' >= -59 & birth_dif_sib_`k' <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar i`k' = _b[trt_`k']
scalar j`k' = _se[trt_`k']
reg scorep trt`k' birth_dif_sib`k' inter`k' white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib`k' >= -59 & birth_dif_sib`k' <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar k`k' = _b[trt`k']
scalar l`k' = _se[trt`k']
}


matrix X = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36\37\38\39\40\41\42\43\44\45\46\47\48\49\50\51\52\53\54\55\56\57\58\59\60\61\62\63\64\65\66\67\68\69\70\71\72\73\74\75\76\77\78\79\80\81\82\83\84\85\86\87\88\89\90\91\92\93\94\95\96\97\98\99\100)
matrix Y = X*(-1)

matrix I = (i1\i2\i3\i4\i5\i6\i7\i8\i9\i10\i11\i12\i13\i14\i15\i16\i17\i18\i19\i20\i21\i22\i23\i24\i25\i26\i27\i28\i29\i30\i31\i32\i33\i34\i35\i36\i37\i38\i39\i40\i41\i42\i43\i44\i45\i46\i47\i48\i49\i50\i51\i52\i53\i54\i55\i56\i57\i58\i59\i60\i61\i62\i63\i64\i65\i66\i67\i68\i69\i70\i71\i72\i73\i74\i75\i76\i77\i78\i79\i80\i81\i82\i83\i84\i85\i86\i87\i88\i89\i90\i91\i92\i93\i94\i95\i96\i97\i98\i99\i100)
matrix J = (j1\j2\j3\j4\j5\j6\j7\j8\j9\j10\j11\j12\j13\j14\j15\j16\j17\j18\j19\j20\j21\j22\j23\j24\j25\j26\j27\j28\j29\j30\j31\j32\j33\j34\j35\j36\j37\j38\j39\j40\j41\j42\j43\j44\j45\j46\j47\j48\j49\j50\j51\j52\j53\j54\j55\j56\j57\j58\j59\j60\j61\j62\j63\j64\j65\j66\j67\j68\j69\j70\j71\j72\j73\j74\j75\j76\j77\j78\j79\j80\j81\j82\j83\j84\j85\j86\j87\j88\j89\j90\j91\j92\j93\j94\j95\j96\j97\j98\j99\j100)

matrix K = (k1\k2\k3\k4\k5\k6\k7\k8\k9\k10\k11\k12\k13\k14\k15\k16\k17\k18\k19\k20\k21\k22\k23\k24\k25\k26\k27\k28\k29\k30\k31\k32\k33\k34\k35\k36\k37\k38\k39\k40\k41\k42\k43\k44\k45\k46\k47\k48\k49\k50\k51\k52\k53\k54\k55\k56\k57\k58\k59\k60\k61\k62\k63\k64\k65\k66\k67\k68\k69\k70\k71\k72\k73\k74\k75\k76\k77\k78\k79\k80\k81\k82\k83\k84\k85\k86\k87\k88\k89\k90\k91\k92\k93\k94\k95\k96\k97\k98\k99\k100)
matrix L = (l1\l2\l3\l4\l5\l6\l7\l8\l9\l10\l11\l12\l13\l14\l15\l16\l17\l18\l19\l20\l21\l22\l23\l24\l25\l26\l27\l28\l29\l30\l31\l32\l33\l34\l35\l36\l37\l38\l39\l40\l41\l42\l43\l44\l45\l46\l47\l48\l49\l50\l51\l52\l53\l54\l55\l56\l57\l58\l59\l60\l61\l62\l63\l64\l65\l66\l67\l68\l69\l70\l71\l72\l73\l74\l75\l76\l77\l78\l79\l80\l81\l82\l83\l84\l85\l86\l87\l88\l89\l90\l91\l92\l93\l94\l95\l96\l97\l98\l99\l100)

matrix Z1 = (Y\0\X)
matrix Z2 = (I\I0\K)

matrix V = (Z1,Z2)
svmat V
keep V1 V2
keep in 1/201

rename V1 X
rename V2 E1

twoway (kdensity E1, w(0.9) lp(solid) lc(black)), ylabel(0(0.02)0.16)  xline(-3.300, lp(dash) lc(black) lw(thick)) xlabel(-4(1)4.0) xtick(-4(0.5)4.5) xline(0, lp(solid) lc(black) lw(thin)) ytitle("Density") xtitle("Point estimates based on moving threshold by one day for +/- 100 days") legend(off) text(0.05 -2.5 "RD estimate: -3.300", size(vsmall)) graphregion(fcolor(white) ifcolor(white) ilcolor(white))
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A15c.pdf", as(pdf) replace

*** D - sample restrictions ***

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar a1 = _b[trt]
scalar a2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997

keep if coh_sib >= 1979
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar b1 = _b[trt]
scalar b2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
keep if birthyear >= 1979
drop if birthmonth <= 8 & birthyear == 1979
keep if birthyear_sib >= 1979
drop if birthmonth_sib <= 8 & birthyear_sib == 1979
drop BO 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar c1 = _b[trt]
scalar c2 = _se[trt]

keep if BO == 1

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar d1 = _b[trt]
scalar d2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
drop BO
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3
gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

rename idO id
merge m:1 id using "Data\Temp\Jul21\birth-oder-siblings.dta"
keep if _merge == 3
drop _merge
rename id idO
drop if BO > 2

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar e1 = _b[trt]
scalar e2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

egen temp1 = min(grade), by(idO)
keep if temp1 == 3

sort idY testyear
egen temp2 = seq(), by(idO)
egen temp3 = max(temp2), by(idO)
keep if temp3 >= 6
egen temp4 = seq(), by(idO)
drop if temp4 > 6
rename temp4 igrade
replace igrade = igrade+2
drop temp*

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar f1 = _b[trt]
scalar f2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\grade3score.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar g1 = _b[trt]
scalar g2 = _se[trt]

use "Data\Temp\Jul21\main_younger-to-older-with-scores.dta", clear
keep if birthyear >= 1976 & birthyear <= 1993
drop if coh_sib <= 1977 | coh_sib >= 1997
 
drop if grade == "KG" | grade == "PK"
destring grade, replace
keep if grade >= 3 & grade <= 8 

egen scorep = rowmean(mathp readp)
drop if scorep == .

rename idY id_sib
merge m:1 id_sib using "Data\Temp\Jul21\KGgradeobs.dta"
keep if _merge == 3
drop _merge
rename id_sib idY

merge 1:1 idY testyear using "Data\Temp\Jul21\gradesyounger.dta"
keep if _merge == 1 | _merge == 3
replace gradeY = "PPK" if _merge == 1
drop _merge 

gen FCAT = (test == "FCAT")

gen ngrade = gradeY
replace ngrade = "00" if gradeY == "PPK" | gradeY == "PK" | gradeY == "KG"
destring ngrade, replace

keep if ngrade > 3

gen trt = (birth_dif_sib > 0)
gen inter = trt*birth_dif_sib

reg scorep trt birth_dif_sib inter white female i.grade i.birthyear i.birthmonth FCAT i.coh_sib female_sib age_dif if birth_dif_sib >= -59 & birth_dif_sib <= 60 & eFRL == 0, cluster(birth_dif_sib)
scalar h1 = _b[trt]
scalar h2 = _se[trt]

matrix A = (a1\b1\c1\d1\e1\f1\g1\h1)
matrix B = (a2\b2\c2\d2\e2\f2\g2\h2)
matrix X = (1\3\5\7\9\11\13\15)

matrix Z = (X,A,B)
svmat Z
keep Z1-Z3
keep in 1/8
rename Z1 X
rename Z2 E
rename Z3 SE
gen U = E+1.96*SE
gen L = E-1.96*SE

twoway (bar E X if X == 1 | X == 3, color(navy)) (bar E X if X == 5 | X == 7 | X == 9, color(dkorange)) (bar E X if X == 11, color(maroon)) (bar E X if X == 13 | X == 15, color(khaki)) (rspike U L X, lp(solid) lw(thin) lc(black)), xlabel(1 "Baseline" 3 `" "September" "cutoff only" "' 5 `" "Fully" "observed" "' 7 `" "First two" "births" "' 9 `" "Parity one" "and two" "' 11 `" "Grades" "3 to 8" "' 13 `" "3rd grade" "scores" "' 15 `" "KG" "attendance" "', labsize(small)) xtitle("Sample restrictions") ytitle("Younger-to-older spillovers in test scores for" "families never on free or reduced price lunch") legend(label(1 "General") label(2 "Birth order related") label(3 "Panel analysis") label(4 "Focal child information related") order(1 2 3 4) rows(2)symx(*0.5) region(lc(none))) ylabel(-7(1)1) ytick(-7.5(0.5)1) graphregion(fcolor(white) ifcolor(white) ilcolor(white)) 
graph export "H:\FKOR\Spillovers\Graph\Jul21\Figure-A15d.pdf", as(pdf) replace

log close 




